# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsWarning(object):
    """
    LogAnalyticsWarning
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsWarning object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param agent_id:
            The value to assign to the agent_id property of this LogAnalyticsWarning.
        :type agent_id: str

        :param host_name:
            The value to assign to the host_name property of this LogAnalyticsWarning.
        :type host_name: str

        :param rule_display_name:
            The value to assign to the rule_display_name property of this LogAnalyticsWarning.
        :type rule_display_name: str

        :param source_name:
            The value to assign to the source_name property of this LogAnalyticsWarning.
        :type source_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsWarning.
        :type compartment_id: str

        :param source_display_name:
            The value to assign to the source_display_name property of this LogAnalyticsWarning.
        :type source_display_name: str

        :param entity_name:
            The value to assign to the entity_name property of this LogAnalyticsWarning.
        :type entity_name: str

        :param time_collected:
            The value to assign to the time_collected property of this LogAnalyticsWarning.
        :type time_collected: datetime

        :param warning_id:
            The value to assign to the warning_id property of this LogAnalyticsWarning.
        :type warning_id: str

        :param time_of_initial_warning:
            The value to assign to the time_of_initial_warning property of this LogAnalyticsWarning.
        :type time_of_initial_warning: datetime

        :param is_active:
            The value to assign to the is_active property of this LogAnalyticsWarning.
        :type is_active: bool

        :param is_suppressed:
            The value to assign to the is_suppressed property of this LogAnalyticsWarning.
        :type is_suppressed: bool

        :param time_of_latest_warning:
            The value to assign to the time_of_latest_warning property of this LogAnalyticsWarning.
        :type time_of_latest_warning: datetime

        :param warning_level:
            The value to assign to the warning_level property of this LogAnalyticsWarning.
        :type warning_level: str

        :param warning_message:
            The value to assign to the warning_message property of this LogAnalyticsWarning.
        :type warning_message: str

        :param pattern_id:
            The value to assign to the pattern_id property of this LogAnalyticsWarning.
        :type pattern_id: str

        :param pattern_text:
            The value to assign to the pattern_text property of this LogAnalyticsWarning.
        :type pattern_text: str

        :param rule_id:
            The value to assign to the rule_id property of this LogAnalyticsWarning.
        :type rule_id: str

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsWarning.
        :type source_id: str

        :param suppressed_by:
            The value to assign to the suppressed_by property of this LogAnalyticsWarning.
        :type suppressed_by: str

        :param entity_id:
            The value to assign to the entity_id property of this LogAnalyticsWarning.
        :type entity_id: str

        :param entity_type:
            The value to assign to the entity_type property of this LogAnalyticsWarning.
        :type entity_type: str

        :param entity_type_display_name:
            The value to assign to the entity_type_display_name property of this LogAnalyticsWarning.
        :type entity_type_display_name: str

        :param type_display_name:
            The value to assign to the type_display_name property of this LogAnalyticsWarning.
        :type type_display_name: str

        :param type_name:
            The value to assign to the type_name property of this LogAnalyticsWarning.
        :type type_name: str

        :param severity:
            The value to assign to the severity property of this LogAnalyticsWarning.
        :type severity: int

        """
        self.swagger_types = {
            'agent_id': 'str',
            'host_name': 'str',
            'rule_display_name': 'str',
            'source_name': 'str',
            'compartment_id': 'str',
            'source_display_name': 'str',
            'entity_name': 'str',
            'time_collected': 'datetime',
            'warning_id': 'str',
            'time_of_initial_warning': 'datetime',
            'is_active': 'bool',
            'is_suppressed': 'bool',
            'time_of_latest_warning': 'datetime',
            'warning_level': 'str',
            'warning_message': 'str',
            'pattern_id': 'str',
            'pattern_text': 'str',
            'rule_id': 'str',
            'source_id': 'str',
            'suppressed_by': 'str',
            'entity_id': 'str',
            'entity_type': 'str',
            'entity_type_display_name': 'str',
            'type_display_name': 'str',
            'type_name': 'str',
            'severity': 'int'
        }

        self.attribute_map = {
            'agent_id': 'agentId',
            'host_name': 'hostName',
            'rule_display_name': 'ruleDisplayName',
            'source_name': 'sourceName',
            'compartment_id': 'compartmentId',
            'source_display_name': 'sourceDisplayName',
            'entity_name': 'entityName',
            'time_collected': 'timeCollected',
            'warning_id': 'warningId',
            'time_of_initial_warning': 'timeOfInitialWarning',
            'is_active': 'isActive',
            'is_suppressed': 'isSuppressed',
            'time_of_latest_warning': 'timeOfLatestWarning',
            'warning_level': 'warningLevel',
            'warning_message': 'warningMessage',
            'pattern_id': 'patternId',
            'pattern_text': 'patternText',
            'rule_id': 'ruleId',
            'source_id': 'sourceId',
            'suppressed_by': 'suppressedBy',
            'entity_id': 'entityId',
            'entity_type': 'entityType',
            'entity_type_display_name': 'entityTypeDisplayName',
            'type_display_name': 'typeDisplayName',
            'type_name': 'typeName',
            'severity': 'severity'
        }

        self._agent_id = None
        self._host_name = None
        self._rule_display_name = None
        self._source_name = None
        self._compartment_id = None
        self._source_display_name = None
        self._entity_name = None
        self._time_collected = None
        self._warning_id = None
        self._time_of_initial_warning = None
        self._is_active = None
        self._is_suppressed = None
        self._time_of_latest_warning = None
        self._warning_level = None
        self._warning_message = None
        self._pattern_id = None
        self._pattern_text = None
        self._rule_id = None
        self._source_id = None
        self._suppressed_by = None
        self._entity_id = None
        self._entity_type = None
        self._entity_type_display_name = None
        self._type_display_name = None
        self._type_name = None
        self._severity = None

    @property
    def agent_id(self):
        """
        Gets the agent_id of this LogAnalyticsWarning.
        The unique identifier of the agent associated with the warning


        :return: The agent_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this LogAnalyticsWarning.
        The unique identifier of the agent associated with the warning


        :param agent_id: The agent_id of this LogAnalyticsWarning.
        :type: str
        """
        self._agent_id = agent_id

    @property
    def host_name(self):
        """
        Gets the host_name of this LogAnalyticsWarning.
        The host containing the agent associated with the warning


        :return: The host_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this LogAnalyticsWarning.
        The host containing the agent associated with the warning


        :param host_name: The host_name of this LogAnalyticsWarning.
        :type: str
        """
        self._host_name = host_name

    @property
    def rule_display_name(self):
        """
        Gets the rule_display_name of this LogAnalyticsWarning.
        The display name of the rule which triggered the warning


        :return: The rule_display_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._rule_display_name

    @rule_display_name.setter
    def rule_display_name(self, rule_display_name):
        """
        Sets the rule_display_name of this LogAnalyticsWarning.
        The display name of the rule which triggered the warning


        :param rule_display_name: The rule_display_name of this LogAnalyticsWarning.
        :type: str
        """
        self._rule_display_name = rule_display_name

    @property
    def source_name(self):
        """
        Gets the source_name of this LogAnalyticsWarning.
        The name of the source associated with the warning


        :return: The source_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this LogAnalyticsWarning.
        The name of the source associated with the warning


        :param source_name: The source_name of this LogAnalyticsWarning.
        :type: str
        """
        self._source_name = source_name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this LogAnalyticsWarning.
        The entity compartment ID.


        :return: The compartment_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsWarning.
        The entity compartment ID.


        :param compartment_id: The compartment_id of this LogAnalyticsWarning.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def source_display_name(self):
        """
        Gets the source_display_name of this LogAnalyticsWarning.
        The display name of the source associated with the warning


        :return: The source_display_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._source_display_name

    @source_display_name.setter
    def source_display_name(self, source_display_name):
        """
        Sets the source_display_name of this LogAnalyticsWarning.
        The display name of the source associated with the warning


        :param source_display_name: The source_display_name of this LogAnalyticsWarning.
        :type: str
        """
        self._source_display_name = source_display_name

    @property
    def entity_name(self):
        """
        Gets the entity_name of this LogAnalyticsWarning.
        The name of the entity associated with the warning


        :return: The entity_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this LogAnalyticsWarning.
        The name of the entity associated with the warning


        :param entity_name: The entity_name of this LogAnalyticsWarning.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def time_collected(self):
        """
        Gets the time_collected of this LogAnalyticsWarning.
        The time at which the warning was most recently collected


        :return: The time_collected of this LogAnalyticsWarning.
        :rtype: datetime
        """
        return self._time_collected

    @time_collected.setter
    def time_collected(self, time_collected):
        """
        Sets the time_collected of this LogAnalyticsWarning.
        The time at which the warning was most recently collected


        :param time_collected: The time_collected of this LogAnalyticsWarning.
        :type: datetime
        """
        self._time_collected = time_collected

    @property
    def warning_id(self):
        """
        Gets the warning_id of this LogAnalyticsWarning.
        The unique identifier of the warning


        :return: The warning_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._warning_id

    @warning_id.setter
    def warning_id(self, warning_id):
        """
        Sets the warning_id of this LogAnalyticsWarning.
        The unique identifier of the warning


        :param warning_id: The warning_id of this LogAnalyticsWarning.
        :type: str
        """
        self._warning_id = warning_id

    @property
    def time_of_initial_warning(self):
        """
        Gets the time_of_initial_warning of this LogAnalyticsWarning.
        The date at which the warning was initially triggered


        :return: The time_of_initial_warning of this LogAnalyticsWarning.
        :rtype: datetime
        """
        return self._time_of_initial_warning

    @time_of_initial_warning.setter
    def time_of_initial_warning(self, time_of_initial_warning):
        """
        Sets the time_of_initial_warning of this LogAnalyticsWarning.
        The date at which the warning was initially triggered


        :param time_of_initial_warning: The time_of_initial_warning of this LogAnalyticsWarning.
        :type: datetime
        """
        self._time_of_initial_warning = time_of_initial_warning

    @property
    def is_active(self):
        """
        Gets the is_active of this LogAnalyticsWarning.
        A flag indicating if the warning is currently active


        :return: The is_active of this LogAnalyticsWarning.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this LogAnalyticsWarning.
        A flag indicating if the warning is currently active


        :param is_active: The is_active of this LogAnalyticsWarning.
        :type: bool
        """
        self._is_active = is_active

    @property
    def is_suppressed(self):
        """
        Gets the is_suppressed of this LogAnalyticsWarning.
        A flag indicating if the warning is currently suppressed


        :return: The is_suppressed of this LogAnalyticsWarning.
        :rtype: bool
        """
        return self._is_suppressed

    @is_suppressed.setter
    def is_suppressed(self, is_suppressed):
        """
        Sets the is_suppressed of this LogAnalyticsWarning.
        A flag indicating if the warning is currently suppressed


        :param is_suppressed: The is_suppressed of this LogAnalyticsWarning.
        :type: bool
        """
        self._is_suppressed = is_suppressed

    @property
    def time_of_latest_warning(self):
        """
        Gets the time_of_latest_warning of this LogAnalyticsWarning.
        The most recent date on which the warning was triggered


        :return: The time_of_latest_warning of this LogAnalyticsWarning.
        :rtype: datetime
        """
        return self._time_of_latest_warning

    @time_of_latest_warning.setter
    def time_of_latest_warning(self, time_of_latest_warning):
        """
        Sets the time_of_latest_warning of this LogAnalyticsWarning.
        The most recent date on which the warning was triggered


        :param time_of_latest_warning: The time_of_latest_warning of this LogAnalyticsWarning.
        :type: datetime
        """
        self._time_of_latest_warning = time_of_latest_warning

    @property
    def warning_level(self):
        """
        Gets the warning_level of this LogAnalyticsWarning.
        The warning level - either pattern, rule, or source.


        :return: The warning_level of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._warning_level

    @warning_level.setter
    def warning_level(self, warning_level):
        """
        Sets the warning_level of this LogAnalyticsWarning.
        The warning level - either pattern, rule, or source.


        :param warning_level: The warning_level of this LogAnalyticsWarning.
        :type: str
        """
        self._warning_level = warning_level

    @property
    def warning_message(self):
        """
        Gets the warning_message of this LogAnalyticsWarning.
        A description of the warning intended for the consumer of the warning.  It will
        usually detail the cause of the warning, may suggest a remedy, and can contain any
        other relevant information the consumer might find useful


        :return: The warning_message of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._warning_message

    @warning_message.setter
    def warning_message(self, warning_message):
        """
        Sets the warning_message of this LogAnalyticsWarning.
        A description of the warning intended for the consumer of the warning.  It will
        usually detail the cause of the warning, may suggest a remedy, and can contain any
        other relevant information the consumer might find useful


        :param warning_message: The warning_message of this LogAnalyticsWarning.
        :type: str
        """
        self._warning_message = warning_message

    @property
    def pattern_id(self):
        """
        Gets the pattern_id of this LogAnalyticsWarning.
        The unique identifier of the warning pattern


        :return: The pattern_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._pattern_id

    @pattern_id.setter
    def pattern_id(self, pattern_id):
        """
        Sets the pattern_id of this LogAnalyticsWarning.
        The unique identifier of the warning pattern


        :param pattern_id: The pattern_id of this LogAnalyticsWarning.
        :type: str
        """
        self._pattern_id = pattern_id

    @property
    def pattern_text(self):
        """
        Gets the pattern_text of this LogAnalyticsWarning.
        The text of the pattern used by the warning


        :return: The pattern_text of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._pattern_text

    @pattern_text.setter
    def pattern_text(self, pattern_text):
        """
        Sets the pattern_text of this LogAnalyticsWarning.
        The text of the pattern used by the warning


        :param pattern_text: The pattern_text of this LogAnalyticsWarning.
        :type: str
        """
        self._pattern_text = pattern_text

    @property
    def rule_id(self):
        """
        Gets the rule_id of this LogAnalyticsWarning.
        The unique identifier of the rule associated with the warning


        :return: The rule_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        """
        Sets the rule_id of this LogAnalyticsWarning.
        The unique identifier of the rule associated with the warning


        :param rule_id: The rule_id of this LogAnalyticsWarning.
        :type: str
        """
        self._rule_id = rule_id

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsWarning.
        The unique identifier of the source associated with the warning


        :return: The source_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsWarning.
        The unique identifier of the source associated with the warning


        :param source_id: The source_id of this LogAnalyticsWarning.
        :type: str
        """
        self._source_id = source_id

    @property
    def suppressed_by(self):
        """
        Gets the suppressed_by of this LogAnalyticsWarning.
        The user who suppressed the warning, or empty if the warning is not suppressed


        :return: The suppressed_by of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._suppressed_by

    @suppressed_by.setter
    def suppressed_by(self, suppressed_by):
        """
        Sets the suppressed_by of this LogAnalyticsWarning.
        The user who suppressed the warning, or empty if the warning is not suppressed


        :param suppressed_by: The suppressed_by of this LogAnalyticsWarning.
        :type: str
        """
        self._suppressed_by = suppressed_by

    @property
    def entity_id(self):
        """
        Gets the entity_id of this LogAnalyticsWarning.
        The unique identifier of the entity associated with the warning


        :return: The entity_id of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this LogAnalyticsWarning.
        The unique identifier of the entity associated with the warning


        :param entity_id: The entity_id of this LogAnalyticsWarning.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def entity_type(self):
        """
        Gets the entity_type of this LogAnalyticsWarning.
        The type of the entity associated with the warning


        :return: The entity_type of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this LogAnalyticsWarning.
        The type of the entity associated with the warning


        :param entity_type: The entity_type of this LogAnalyticsWarning.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def entity_type_display_name(self):
        """
        Gets the entity_type_display_name of this LogAnalyticsWarning.
        The display name of the entity type associated with the warning


        :return: The entity_type_display_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._entity_type_display_name

    @entity_type_display_name.setter
    def entity_type_display_name(self, entity_type_display_name):
        """
        Sets the entity_type_display_name of this LogAnalyticsWarning.
        The display name of the entity type associated with the warning


        :param entity_type_display_name: The entity_type_display_name of this LogAnalyticsWarning.
        :type: str
        """
        self._entity_type_display_name = entity_type_display_name

    @property
    def type_display_name(self):
        """
        Gets the type_display_name of this LogAnalyticsWarning.
        The display name of the warning type


        :return: The type_display_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._type_display_name

    @type_display_name.setter
    def type_display_name(self, type_display_name):
        """
        Sets the type_display_name of this LogAnalyticsWarning.
        The display name of the warning type


        :param type_display_name: The type_display_name of this LogAnalyticsWarning.
        :type: str
        """
        self._type_display_name = type_display_name

    @property
    def type_name(self):
        """
        Gets the type_name of this LogAnalyticsWarning.
        The internal name of the warning


        :return: The type_name of this LogAnalyticsWarning.
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """
        Sets the type_name of this LogAnalyticsWarning.
        The internal name of the warning


        :param type_name: The type_name of this LogAnalyticsWarning.
        :type: str
        """
        self._type_name = type_name

    @property
    def severity(self):
        """
        Gets the severity of this LogAnalyticsWarning.
        The warning severity


        :return: The severity of this LogAnalyticsWarning.
        :rtype: int
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this LogAnalyticsWarning.
        The warning severity


        :param severity: The severity of this LogAnalyticsWarning.
        :type: int
        """
        self._severity = severity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QuickPickSummary(object):
    """
    Summary of quick pick query objects that contains the quick pick queries.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QuickPickSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param quick_pick_name:
            The value to assign to the quick_pick_name property of this QuickPickSummary.
        :type quick_pick_name: str

        :param quick_pick_query:
            The value to assign to the quick_pick_query property of this QuickPickSummary.
        :type quick_pick_query: str

        """
        self.swagger_types = {
            'quick_pick_name': 'str',
            'quick_pick_query': 'str'
        }

        self.attribute_map = {
            'quick_pick_name': 'quickPickName',
            'quick_pick_query': 'quickPickQuery'
        }

        self._quick_pick_name = None
        self._quick_pick_query = None

    @property
    def quick_pick_name(self):
        """
        **[Required]** Gets the quick_pick_name of this QuickPickSummary.
        Quick pick name for the query.


        :return: The quick_pick_name of this QuickPickSummary.
        :rtype: str
        """
        return self._quick_pick_name

    @quick_pick_name.setter
    def quick_pick_name(self, quick_pick_name):
        """
        Sets the quick_pick_name of this QuickPickSummary.
        Quick pick name for the query.


        :param quick_pick_name: The quick_pick_name of this QuickPickSummary.
        :type: str
        """
        self._quick_pick_name = quick_pick_name

    @property
    def quick_pick_query(self):
        """
        **[Required]** Gets the quick_pick_query of this QuickPickSummary.
        Query for the quick pick.


        :return: The quick_pick_query of this QuickPickSummary.
        :rtype: str
        """
        return self._quick_pick_query

    @quick_pick_query.setter
    def quick_pick_query(self, quick_pick_query):
        """
        Sets the quick_pick_query of this QuickPickSummary.
        Query for the quick pick.


        :param quick_pick_query: The quick_pick_query of this QuickPickSummary.
        :type: str
        """
        self._quick_pick_query = quick_pick_query

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApproveDeploymentDetails(object):
    """
    The stage information for submitting for approval.
    """

    #: A constant which can be used with the action property of a ApproveDeploymentDetails.
    #: This constant has a value of "APPROVE"
    ACTION_APPROVE = "APPROVE"

    #: A constant which can be used with the action property of a ApproveDeploymentDetails.
    #: This constant has a value of "REJECT"
    ACTION_REJECT = "REJECT"

    def __init__(self, **kwargs):
        """
        Initializes a new ApproveDeploymentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_stage_id:
            The value to assign to the deploy_stage_id property of this ApproveDeploymentDetails.
        :type deploy_stage_id: str

        :param reason:
            The value to assign to the reason property of this ApproveDeploymentDetails.
        :type reason: str

        :param action:
            The value to assign to the action property of this ApproveDeploymentDetails.
            Allowed values for this property are: "APPROVE", "REJECT"
        :type action: str

        """
        self.swagger_types = {
            'deploy_stage_id': 'str',
            'reason': 'str',
            'action': 'str'
        }

        self.attribute_map = {
            'deploy_stage_id': 'deployStageId',
            'reason': 'reason',
            'action': 'action'
        }

        self._deploy_stage_id = None
        self._reason = None
        self._action = None

    @property
    def deploy_stage_id(self):
        """
        **[Required]** Gets the deploy_stage_id of this ApproveDeploymentDetails.
        The `OCID`__ of the stage which is marked for approval.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The deploy_stage_id of this ApproveDeploymentDetails.
        :rtype: str
        """
        return self._deploy_stage_id

    @deploy_stage_id.setter
    def deploy_stage_id(self, deploy_stage_id):
        """
        Sets the deploy_stage_id of this ApproveDeploymentDetails.
        The `OCID`__ of the stage which is marked for approval.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param deploy_stage_id: The deploy_stage_id of this ApproveDeploymentDetails.
        :type: str
        """
        self._deploy_stage_id = deploy_stage_id

    @property
    def reason(self):
        """
        Gets the reason of this ApproveDeploymentDetails.
        The reason for approving or rejecting the deployment.


        :return: The reason of this ApproveDeploymentDetails.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this ApproveDeploymentDetails.
        The reason for approving or rejecting the deployment.


        :param reason: The reason of this ApproveDeploymentDetails.
        :type: str
        """
        self._reason = reason

    @property
    def action(self):
        """
        **[Required]** Gets the action of this ApproveDeploymentDetails.
        The action of Approve or Reject.

        Allowed values for this property are: "APPROVE", "REJECT"


        :return: The action of this ApproveDeploymentDetails.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ApproveDeploymentDetails.
        The action of Approve or Reject.


        :param action: The action of this ApproveDeploymentDetails.
        :type: str
        """
        allowed_values = ["APPROVE", "REJECT"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            raise ValueError(
                "Invalid value for `action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._action = action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExternalPublicationValidation(object):
    """
    The information about external published task validation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExternalPublicationValidation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_message_count:
            The value to assign to the total_message_count property of this ExternalPublicationValidation.
        :type total_message_count: int

        :param error_message_count:
            The value to assign to the error_message_count property of this ExternalPublicationValidation.
        :type error_message_count: int

        :param warn_message_count:
            The value to assign to the warn_message_count property of this ExternalPublicationValidation.
        :type warn_message_count: int

        :param info_message_count:
            The value to assign to the info_message_count property of this ExternalPublicationValidation.
        :type info_message_count: int

        :param validation_messages:
            The value to assign to the validation_messages property of this ExternalPublicationValidation.
        :type validation_messages: dict(str, list[ValidationMessage])

        :param key:
            The value to assign to the key property of this ExternalPublicationValidation.
        :type key: str

        """
        self.swagger_types = {
            'total_message_count': 'int',
            'error_message_count': 'int',
            'warn_message_count': 'int',
            'info_message_count': 'int',
            'validation_messages': 'dict(str, list[ValidationMessage])',
            'key': 'str'
        }

        self.attribute_map = {
            'total_message_count': 'totalMessageCount',
            'error_message_count': 'errorMessageCount',
            'warn_message_count': 'warnMessageCount',
            'info_message_count': 'infoMessageCount',
            'validation_messages': 'validationMessages',
            'key': 'key'
        }

        self._total_message_count = None
        self._error_message_count = None
        self._warn_message_count = None
        self._info_message_count = None
        self._validation_messages = None
        self._key = None

    @property
    def total_message_count(self):
        """
        Gets the total_message_count of this ExternalPublicationValidation.
        Total number of validation messages.


        :return: The total_message_count of this ExternalPublicationValidation.
        :rtype: int
        """
        return self._total_message_count

    @total_message_count.setter
    def total_message_count(self, total_message_count):
        """
        Sets the total_message_count of this ExternalPublicationValidation.
        Total number of validation messages.


        :param total_message_count: The total_message_count of this ExternalPublicationValidation.
        :type: int
        """
        self._total_message_count = total_message_count

    @property
    def error_message_count(self):
        """
        Gets the error_message_count of this ExternalPublicationValidation.
        Total number of validation error messages.


        :return: The error_message_count of this ExternalPublicationValidation.
        :rtype: int
        """
        return self._error_message_count

    @error_message_count.setter
    def error_message_count(self, error_message_count):
        """
        Sets the error_message_count of this ExternalPublicationValidation.
        Total number of validation error messages.


        :param error_message_count: The error_message_count of this ExternalPublicationValidation.
        :type: int
        """
        self._error_message_count = error_message_count

    @property
    def warn_message_count(self):
        """
        Gets the warn_message_count of this ExternalPublicationValidation.
        Total number of validation warning messages.


        :return: The warn_message_count of this ExternalPublicationValidation.
        :rtype: int
        """
        return self._warn_message_count

    @warn_message_count.setter
    def warn_message_count(self, warn_message_count):
        """
        Sets the warn_message_count of this ExternalPublicationValidation.
        Total number of validation warning messages.


        :param warn_message_count: The warn_message_count of this ExternalPublicationValidation.
        :type: int
        """
        self._warn_message_count = warn_message_count

    @property
    def info_message_count(self):
        """
        Gets the info_message_count of this ExternalPublicationValidation.
        Total number of validation information messages.


        :return: The info_message_count of this ExternalPublicationValidation.
        :rtype: int
        """
        return self._info_message_count

    @info_message_count.setter
    def info_message_count(self, info_message_count):
        """
        Sets the info_message_count of this ExternalPublicationValidation.
        Total number of validation information messages.


        :param info_message_count: The info_message_count of this ExternalPublicationValidation.
        :type: int
        """
        self._info_message_count = info_message_count

    @property
    def validation_messages(self):
        """
        Gets the validation_messages of this ExternalPublicationValidation.
        Detailed information of the data flow object validation.


        :return: The validation_messages of this ExternalPublicationValidation.
        :rtype: dict(str, list[ValidationMessage])
        """
        return self._validation_messages

    @validation_messages.setter
    def validation_messages(self, validation_messages):
        """
        Sets the validation_messages of this ExternalPublicationValidation.
        Detailed information of the data flow object validation.


        :param validation_messages: The validation_messages of this ExternalPublicationValidation.
        :type: dict(str, list[ValidationMessage])
        """
        self._validation_messages = validation_messages

    @property
    def key(self):
        """
        Gets the key of this ExternalPublicationValidation.
        Objects use a 36 character key as unique ID. It is system generated and cannot be modified.


        :return: The key of this ExternalPublicationValidation.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ExternalPublicationValidation.
        Objects use a 36 character key as unique ID. It is system generated and cannot be modified.


        :param key: The key of this ExternalPublicationValidation.
        :type: str
        """
        self._key = key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperatorActionSummary(object):
    """
    Details of the operator action. Operator actions are pre-defined set of commands available to the operator on different layers of the infrastructure.
    """

    #: A constant which can be used with the lifecycle_state property of a OperatorActionSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OperatorActionSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new OperatorActionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OperatorActionSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this OperatorActionSummary.
        :type name: str

        :param component:
            The value to assign to the component property of this OperatorActionSummary.
        :type component: str

        :param compartment_id:
            The value to assign to the compartment_id property of this OperatorActionSummary.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OperatorActionSummary.
            Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param description:
            The value to assign to the description property of this OperatorActionSummary.
        :type description: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'component': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'component': 'component',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'description': 'description'
        }

        self._id = None
        self._name = None
        self._component = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._description = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OperatorActionSummary.
        Unique identifier assigned by Oracle to an operator action.


        :return: The id of this OperatorActionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OperatorActionSummary.
        Unique identifier assigned by Oracle to an operator action.


        :param id: The id of this OperatorActionSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OperatorActionSummary.
        Name of the operator action.


        :return: The name of this OperatorActionSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OperatorActionSummary.
        Name of the operator action.


        :param name: The name of this OperatorActionSummary.
        :type: str
        """
        self._name = name

    @property
    def component(self):
        """
        Gets the component of this OperatorActionSummary.
        Name of the component for which the operator action is applicable.


        :return: The component of this OperatorActionSummary.
        :rtype: str
        """
        return self._component

    @component.setter
    def component(self, component):
        """
        Sets the component of this OperatorActionSummary.
        Name of the component for which the operator action is applicable.


        :param component: The component of this OperatorActionSummary.
        :type: str
        """
        self._component = component

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this OperatorActionSummary.
        compartmentId for which the OperatorAction is applicable


        :return: The compartment_id of this OperatorActionSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this OperatorActionSummary.
        compartmentId for which the OperatorAction is applicable


        :param compartment_id: The compartment_id of this OperatorActionSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this OperatorActionSummary.
        The current lifecycle state of the operator action.

        Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OperatorActionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OperatorActionSummary.
        The current lifecycle state of the operator action.


        :param lifecycle_state: The lifecycle_state of this OperatorActionSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def description(self):
        """
        Gets the description of this OperatorActionSummary.
        Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made
        available to the operator under this operator action.


        :return: The description of this OperatorActionSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OperatorActionSummary.
        Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made
        available to the operator under this operator action.


        :param description: The description of this OperatorActionSummary.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .monitor_configuration import MonitorConfiguration
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScriptedRestMonitorConfiguration(MonitorConfiguration):
    """
    Configuration details for the SCRIPTED_REST monitor type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScriptedRestMonitorConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.apm_synthetics.models.ScriptedRestMonitorConfiguration.config_type` attribute
        of this class is ``SCRIPTED_REST_CONFIG`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this ScriptedRestMonitorConfiguration.
            Allowed values for this property are: "BROWSER_CONFIG", "SCRIPTED_BROWSER_CONFIG", "REST_CONFIG", "SCRIPTED_REST_CONFIG"
        :type config_type: str

        :param is_failure_retried:
            The value to assign to the is_failure_retried property of this ScriptedRestMonitorConfiguration.
        :type is_failure_retried: bool

        """
        self.swagger_types = {
            'config_type': 'str',
            'is_failure_retried': 'bool'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'is_failure_retried': 'isFailureRetried'
        }

        self._config_type = None
        self._is_failure_retried = None
        self._config_type = 'SCRIPTED_REST_CONFIG'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseIOAggregateMetrics(object):
    """
    The database Input/Output metric details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseIOAggregateMetrics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param iops:
            The value to assign to the iops property of this DatabaseIOAggregateMetrics.
        :type iops: list[oci.database_management.models.MetricDataPoint]

        :param io_throughput:
            The value to assign to the io_throughput property of this DatabaseIOAggregateMetrics.
        :type io_throughput: list[oci.database_management.models.MetricDataPoint]

        """
        self.swagger_types = {
            'iops': 'list[MetricDataPoint]',
            'io_throughput': 'list[MetricDataPoint]'
        }

        self.attribute_map = {
            'iops': 'iops',
            'io_throughput': 'ioThroughput'
        }

        self._iops = None
        self._io_throughput = None

    @property
    def iops(self):
        """
        Gets the iops of this DatabaseIOAggregateMetrics.
        A list of the Input/Output Operations Per Second metrics grouped by IOType for a specific database.


        :return: The iops of this DatabaseIOAggregateMetrics.
        :rtype: list[oci.database_management.models.MetricDataPoint]
        """
        return self._iops

    @iops.setter
    def iops(self, iops):
        """
        Sets the iops of this DatabaseIOAggregateMetrics.
        A list of the Input/Output Operations Per Second metrics grouped by IOType for a specific database.


        :param iops: The iops of this DatabaseIOAggregateMetrics.
        :type: list[oci.database_management.models.MetricDataPoint]
        """
        self._iops = iops

    @property
    def io_throughput(self):
        """
        Gets the io_throughput of this DatabaseIOAggregateMetrics.
        A list of the IOThroughput metrics grouped for a specific database.


        :return: The io_throughput of this DatabaseIOAggregateMetrics.
        :rtype: list[oci.database_management.models.MetricDataPoint]
        """
        return self._io_throughput

    @io_throughput.setter
    def io_throughput(self, io_throughput):
        """
        Sets the io_throughput of this DatabaseIOAggregateMetrics.
        A list of the IOThroughput metrics grouped for a specific database.


        :param io_throughput: The io_throughput of this DatabaseIOAggregateMetrics.
        :type: list[oci.database_management.models.MetricDataPoint]
        """
        self._io_throughput = io_throughput

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateBackendDetails(object):
    """
    The configuration details for updating a backend server.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateBackendDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param weight:
            The value to assign to the weight property of this UpdateBackendDetails.
        :type weight: int

        :param is_backup:
            The value to assign to the is_backup property of this UpdateBackendDetails.
        :type is_backup: bool

        :param is_drain:
            The value to assign to the is_drain property of this UpdateBackendDetails.
        :type is_drain: bool

        :param is_offline:
            The value to assign to the is_offline property of this UpdateBackendDetails.
        :type is_offline: bool

        """
        self.swagger_types = {
            'weight': 'int',
            'is_backup': 'bool',
            'is_drain': 'bool',
            'is_offline': 'bool'
        }

        self.attribute_map = {
            'weight': 'weight',
            'is_backup': 'isBackup',
            'is_drain': 'isDrain',
            'is_offline': 'isOffline'
        }

        self._weight = None
        self._is_backup = None
        self._is_drain = None
        self._is_offline = None

    @property
    def weight(self):
        """
        Gets the weight of this UpdateBackendDetails.
        The load balancing policy weight assigned to the server. Backend servers with a higher weight receive a larger
        proportion of incoming traffic. For example, a server weighted '3' receives three times the number of new connections
        as a server weighted '1'.
        For more information about load balancing policies, see
        `How Load Balancing Policies Work`__.

        Example: `3`

        __ https://docs.cloud.oracle.com/Content/Balance/Reference/lbpolicies.htm


        :return: The weight of this UpdateBackendDetails.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """
        Sets the weight of this UpdateBackendDetails.
        The load balancing policy weight assigned to the server. Backend servers with a higher weight receive a larger
        proportion of incoming traffic. For example, a server weighted '3' receives three times the number of new connections
        as a server weighted '1'.
        For more information about load balancing policies, see
        `How Load Balancing Policies Work`__.

        Example: `3`

        __ https://docs.cloud.oracle.com/Content/Balance/Reference/lbpolicies.htm


        :param weight: The weight of this UpdateBackendDetails.
        :type: int
        """
        self._weight = weight

    @property
    def is_backup(self):
        """
        Gets the is_backup of this UpdateBackendDetails.
        Whether the network load balancer should treat this server as a backup unit. If `true`, then the network load balancer forwards no ingress
        traffic to this backend server unless all other backend servers not marked as \"isBackup\" fail the health check policy.

        Example: `false`


        :return: The is_backup of this UpdateBackendDetails.
        :rtype: bool
        """
        return self._is_backup

    @is_backup.setter
    def is_backup(self, is_backup):
        """
        Sets the is_backup of this UpdateBackendDetails.
        Whether the network load balancer should treat this server as a backup unit. If `true`, then the network load balancer forwards no ingress
        traffic to this backend server unless all other backend servers not marked as \"isBackup\" fail the health check policy.

        Example: `false`


        :param is_backup: The is_backup of this UpdateBackendDetails.
        :type: bool
        """
        self._is_backup = is_backup

    @property
    def is_drain(self):
        """
        Gets the is_drain of this UpdateBackendDetails.
        Whether the network load balancer should drain this server. Servers marked \"isDrain\" receive no
        incoming traffic.

        Example: `false`


        :return: The is_drain of this UpdateBackendDetails.
        :rtype: bool
        """
        return self._is_drain

    @is_drain.setter
    def is_drain(self, is_drain):
        """
        Sets the is_drain of this UpdateBackendDetails.
        Whether the network load balancer should drain this server. Servers marked \"isDrain\" receive no
        incoming traffic.

        Example: `false`


        :param is_drain: The is_drain of this UpdateBackendDetails.
        :type: bool
        """
        self._is_drain = is_drain

    @property
    def is_offline(self):
        """
        Gets the is_offline of this UpdateBackendDetails.
        Whether the network load balancer should treat this server as offline. Offline servers receive no incoming
        traffic.

        Example: `false`


        :return: The is_offline of this UpdateBackendDetails.
        :rtype: bool
        """
        return self._is_offline

    @is_offline.setter
    def is_offline(self, is_offline):
        """
        Sets the is_offline of this UpdateBackendDetails.
        Whether the network load balancer should treat this server as offline. Offline servers receive no incoming
        traffic.

        Example: `false`


        :param is_offline: The is_offline of this UpdateBackendDetails.
        :type: bool
        """
        self._is_offline = is_offline

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TablespaceSummary(object):
    """
    The summary of a tablespace.
    """

    #: A constant which can be used with the type property of a TablespaceSummary.
    #: This constant has a value of "UNDO"
    TYPE_UNDO = "UNDO"

    #: A constant which can be used with the type property of a TablespaceSummary.
    #: This constant has a value of "LOST_WRITE_PROTECTION"
    TYPE_LOST_WRITE_PROTECTION = "LOST_WRITE_PROTECTION"

    #: A constant which can be used with the type property of a TablespaceSummary.
    #: This constant has a value of "PERMANENT"
    TYPE_PERMANENT = "PERMANENT"

    #: A constant which can be used with the type property of a TablespaceSummary.
    #: This constant has a value of "TEMPORARY"
    TYPE_TEMPORARY = "TEMPORARY"

    #: A constant which can be used with the status property of a TablespaceSummary.
    #: This constant has a value of "ONLINE"
    STATUS_ONLINE = "ONLINE"

    #: A constant which can be used with the status property of a TablespaceSummary.
    #: This constant has a value of "OFFLINE"
    STATUS_OFFLINE = "OFFLINE"

    #: A constant which can be used with the status property of a TablespaceSummary.
    #: This constant has a value of "READ_ONLY"
    STATUS_READ_ONLY = "READ_ONLY"

    #: A constant which can be used with the logging property of a TablespaceSummary.
    #: This constant has a value of "LOGGING"
    LOGGING_LOGGING = "LOGGING"

    #: A constant which can be used with the logging property of a TablespaceSummary.
    #: This constant has a value of "NOLOGGING"
    LOGGING_NOLOGGING = "NOLOGGING"

    #: A constant which can be used with the extent_management property of a TablespaceSummary.
    #: This constant has a value of "LOCAL"
    EXTENT_MANAGEMENT_LOCAL = "LOCAL"

    #: A constant which can be used with the extent_management property of a TablespaceSummary.
    #: This constant has a value of "DICTIONARY"
    EXTENT_MANAGEMENT_DICTIONARY = "DICTIONARY"

    #: A constant which can be used with the allocation_type property of a TablespaceSummary.
    #: This constant has a value of "SYSTEM"
    ALLOCATION_TYPE_SYSTEM = "SYSTEM"

    #: A constant which can be used with the allocation_type property of a TablespaceSummary.
    #: This constant has a value of "UNIFORM"
    ALLOCATION_TYPE_UNIFORM = "UNIFORM"

    #: A constant which can be used with the allocation_type property of a TablespaceSummary.
    #: This constant has a value of "USER"
    ALLOCATION_TYPE_USER = "USER"

    #: A constant which can be used with the segment_space_management property of a TablespaceSummary.
    #: This constant has a value of "MANUAL"
    SEGMENT_SPACE_MANAGEMENT_MANUAL = "MANUAL"

    #: A constant which can be used with the segment_space_management property of a TablespaceSummary.
    #: This constant has a value of "AUTO"
    SEGMENT_SPACE_MANAGEMENT_AUTO = "AUTO"

    #: A constant which can be used with the default_table_compression property of a TablespaceSummary.
    #: This constant has a value of "ENABLED"
    DEFAULT_TABLE_COMPRESSION_ENABLED = "ENABLED"

    #: A constant which can be used with the default_table_compression property of a TablespaceSummary.
    #: This constant has a value of "DISABLED"
    DEFAULT_TABLE_COMPRESSION_DISABLED = "DISABLED"

    #: A constant which can be used with the retention property of a TablespaceSummary.
    #: This constant has a value of "GUARANTEE"
    RETENTION_GUARANTEE = "GUARANTEE"

    #: A constant which can be used with the retention property of a TablespaceSummary.
    #: This constant has a value of "NOGUARANTEE"
    RETENTION_NOGUARANTEE = "NOGUARANTEE"

    #: A constant which can be used with the retention property of a TablespaceSummary.
    #: This constant has a value of "NOT_APPLY"
    RETENTION_NOT_APPLY = "NOT_APPLY"

    #: A constant which can be used with the predicate_evaluation property of a TablespaceSummary.
    #: This constant has a value of "HOST"
    PREDICATE_EVALUATION_HOST = "HOST"

    #: A constant which can be used with the predicate_evaluation property of a TablespaceSummary.
    #: This constant has a value of "STORAGE"
    PREDICATE_EVALUATION_STORAGE = "STORAGE"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "BASIC"
    COMPRESS_FOR_BASIC = "BASIC"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "ADVANCED"
    COMPRESS_FOR_ADVANCED = "ADVANCED"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "QUERY_LOW"
    COMPRESS_FOR_QUERY_LOW = "QUERY_LOW"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "QUERY_HIGH"
    COMPRESS_FOR_QUERY_HIGH = "QUERY_HIGH"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "ARCHIVE_LOW"
    COMPRESS_FOR_ARCHIVE_LOW = "ARCHIVE_LOW"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "ARCHIVE_HIGH"
    COMPRESS_FOR_ARCHIVE_HIGH = "ARCHIVE_HIGH"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "DIRECT_LOAD_ONLY"
    COMPRESS_FOR_DIRECT_LOAD_ONLY = "DIRECT_LOAD_ONLY"

    #: A constant which can be used with the compress_for property of a TablespaceSummary.
    #: This constant has a value of "FOR_ALL_OPERATIONS"
    COMPRESS_FOR_FOR_ALL_OPERATIONS = "FOR_ALL_OPERATIONS"

    #: A constant which can be used with the default_in_memory property of a TablespaceSummary.
    #: This constant has a value of "ENABLED"
    DEFAULT_IN_MEMORY_ENABLED = "ENABLED"

    #: A constant which can be used with the default_in_memory property of a TablespaceSummary.
    #: This constant has a value of "DISABLED"
    DEFAULT_IN_MEMORY_DISABLED = "DISABLED"

    #: A constant which can be used with the default_in_memory_priority property of a TablespaceSummary.
    #: This constant has a value of "LOW"
    DEFAULT_IN_MEMORY_PRIORITY_LOW = "LOW"

    #: A constant which can be used with the default_in_memory_priority property of a TablespaceSummary.
    #: This constant has a value of "MEDIUM"
    DEFAULT_IN_MEMORY_PRIORITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the default_in_memory_priority property of a TablespaceSummary.
    #: This constant has a value of "HIGH"
    DEFAULT_IN_MEMORY_PRIORITY_HIGH = "HIGH"

    #: A constant which can be used with the default_in_memory_priority property of a TablespaceSummary.
    #: This constant has a value of "CRITICAL"
    DEFAULT_IN_MEMORY_PRIORITY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the default_in_memory_priority property of a TablespaceSummary.
    #: This constant has a value of "NONE"
    DEFAULT_IN_MEMORY_PRIORITY_NONE = "NONE"

    #: A constant which can be used with the default_in_memory_distribute property of a TablespaceSummary.
    #: This constant has a value of "AUTO"
    DEFAULT_IN_MEMORY_DISTRIBUTE_AUTO = "AUTO"

    #: A constant which can be used with the default_in_memory_distribute property of a TablespaceSummary.
    #: This constant has a value of "BY_ROWID_RANGE"
    DEFAULT_IN_MEMORY_DISTRIBUTE_BY_ROWID_RANGE = "BY_ROWID_RANGE"

    #: A constant which can be used with the default_in_memory_distribute property of a TablespaceSummary.
    #: This constant has a value of "BY_PARTITION"
    DEFAULT_IN_MEMORY_DISTRIBUTE_BY_PARTITION = "BY_PARTITION"

    #: A constant which can be used with the default_in_memory_distribute property of a TablespaceSummary.
    #: This constant has a value of "BY_SUBPARTITION"
    DEFAULT_IN_MEMORY_DISTRIBUTE_BY_SUBPARTITION = "BY_SUBPARTITION"

    #: A constant which can be used with the default_in_memory_compression property of a TablespaceSummary.
    #: This constant has a value of "NO_MEMCOMPRESS"
    DEFAULT_IN_MEMORY_COMPRESSION_NO_MEMCOMPRESS = "NO_MEMCOMPRESS"

    #: A constant which can be used with the default_in_memory_compression property of a TablespaceSummary.
    #: This constant has a value of "FOR_DML"
    DEFAULT_IN_MEMORY_COMPRESSION_FOR_DML = "FOR_DML"

    #: A constant which can be used with the default_in_memory_compression property of a TablespaceSummary.
    #: This constant has a value of "FOR_QUERY_LOW"
    DEFAULT_IN_MEMORY_COMPRESSION_FOR_QUERY_LOW = "FOR_QUERY_LOW"

    #: A constant which can be used with the default_in_memory_compression property of a TablespaceSummary.
    #: This constant has a value of "FOR_QUERY_HIGH"
    DEFAULT_IN_MEMORY_COMPRESSION_FOR_QUERY_HIGH = "FOR_QUERY_HIGH"

    #: A constant which can be used with the default_in_memory_compression property of a TablespaceSummary.
    #: This constant has a value of "FOR_CAPACITY_LOW"
    DEFAULT_IN_MEMORY_COMPRESSION_FOR_CAPACITY_LOW = "FOR_CAPACITY_LOW"

    #: A constant which can be used with the default_in_memory_compression property of a TablespaceSummary.
    #: This constant has a value of "FOR_CAPACITY_HIGH"
    DEFAULT_IN_MEMORY_COMPRESSION_FOR_CAPACITY_HIGH = "FOR_CAPACITY_HIGH"

    #: A constant which can be used with the default_in_memory_duplicate property of a TablespaceSummary.
    #: This constant has a value of "NO_DUPLICATE"
    DEFAULT_IN_MEMORY_DUPLICATE_NO_DUPLICATE = "NO_DUPLICATE"

    #: A constant which can be used with the default_in_memory_duplicate property of a TablespaceSummary.
    #: This constant has a value of "DUPLICATE"
    DEFAULT_IN_MEMORY_DUPLICATE_DUPLICATE = "DUPLICATE"

    #: A constant which can be used with the default_in_memory_duplicate property of a TablespaceSummary.
    #: This constant has a value of "DUPLICATE_ALL"
    DEFAULT_IN_MEMORY_DUPLICATE_DUPLICATE_ALL = "DUPLICATE_ALL"

    #: A constant which can be used with the shared property of a TablespaceSummary.
    #: This constant has a value of "SHARED"
    SHARED_SHARED = "SHARED"

    #: A constant which can be used with the shared property of a TablespaceSummary.
    #: This constant has a value of "LOCAL_ON_LEAF"
    SHARED_LOCAL_ON_LEAF = "LOCAL_ON_LEAF"

    #: A constant which can be used with the shared property of a TablespaceSummary.
    #: This constant has a value of "LOCAL_ON_ALL"
    SHARED_LOCAL_ON_ALL = "LOCAL_ON_ALL"

    #: A constant which can be used with the default_index_compression property of a TablespaceSummary.
    #: This constant has a value of "ENABLED"
    DEFAULT_INDEX_COMPRESSION_ENABLED = "ENABLED"

    #: A constant which can be used with the default_index_compression property of a TablespaceSummary.
    #: This constant has a value of "DISABLED"
    DEFAULT_INDEX_COMPRESSION_DISABLED = "DISABLED"

    #: A constant which can be used with the index_compress_for property of a TablespaceSummary.
    #: This constant has a value of "ADVANCED_LOW"
    INDEX_COMPRESS_FOR_ADVANCED_LOW = "ADVANCED_LOW"

    #: A constant which can be used with the index_compress_for property of a TablespaceSummary.
    #: This constant has a value of "ADVANCED_HIGH"
    INDEX_COMPRESS_FOR_ADVANCED_HIGH = "ADVANCED_HIGH"

    #: A constant which can be used with the default_in_memory_service property of a TablespaceSummary.
    #: This constant has a value of "DEFAULT"
    DEFAULT_IN_MEMORY_SERVICE_DEFAULT = "DEFAULT"

    #: A constant which can be used with the default_in_memory_service property of a TablespaceSummary.
    #: This constant has a value of "NONE"
    DEFAULT_IN_MEMORY_SERVICE_NONE = "NONE"

    #: A constant which can be used with the default_in_memory_service property of a TablespaceSummary.
    #: This constant has a value of "ALL"
    DEFAULT_IN_MEMORY_SERVICE_ALL = "ALL"

    #: A constant which can be used with the default_in_memory_service property of a TablespaceSummary.
    #: This constant has a value of "USER_DEFINED"
    DEFAULT_IN_MEMORY_SERVICE_USER_DEFINED = "USER_DEFINED"

    #: A constant which can be used with the lost_write_protect property of a TablespaceSummary.
    #: This constant has a value of "ENABLED"
    LOST_WRITE_PROTECT_ENABLED = "ENABLED"

    #: A constant which can be used with the lost_write_protect property of a TablespaceSummary.
    #: This constant has a value of "PROTECT_OFF"
    LOST_WRITE_PROTECT_PROTECT_OFF = "PROTECT_OFF"

    #: A constant which can be used with the lost_write_protect property of a TablespaceSummary.
    #: This constant has a value of "SUSPEND"
    LOST_WRITE_PROTECT_SUSPEND = "SUSPEND"

    def __init__(self, **kwargs):
        """
        Initializes a new TablespaceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this TablespaceSummary.
        :type name: str

        :param type:
            The value to assign to the type property of this TablespaceSummary.
            Allowed values for this property are: "UNDO", "LOST_WRITE_PROTECTION", "PERMANENT", "TEMPORARY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param status:
            The value to assign to the status property of this TablespaceSummary.
            Allowed values for this property are: "ONLINE", "OFFLINE", "READ_ONLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param block_size_bytes:
            The value to assign to the block_size_bytes property of this TablespaceSummary.
        :type block_size_bytes: float

        :param logging:
            The value to assign to the logging property of this TablespaceSummary.
            Allowed values for this property are: "LOGGING", "NOLOGGING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type logging: str

        :param is_force_logging:
            The value to assign to the is_force_logging property of this TablespaceSummary.
        :type is_force_logging: bool

        :param extent_management:
            The value to assign to the extent_management property of this TablespaceSummary.
            Allowed values for this property are: "LOCAL", "DICTIONARY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type extent_management: str

        :param allocation_type:
            The value to assign to the allocation_type property of this TablespaceSummary.
            Allowed values for this property are: "SYSTEM", "UNIFORM", "USER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type allocation_type: str

        :param is_plugged_in:
            The value to assign to the is_plugged_in property of this TablespaceSummary.
        :type is_plugged_in: bool

        :param segment_space_management:
            The value to assign to the segment_space_management property of this TablespaceSummary.
            Allowed values for this property are: "MANUAL", "AUTO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type segment_space_management: str

        :param default_table_compression:
            The value to assign to the default_table_compression property of this TablespaceSummary.
            Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_table_compression: str

        :param retention:
            The value to assign to the retention property of this TablespaceSummary.
            Allowed values for this property are: "GUARANTEE", "NOGUARANTEE", "NOT_APPLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type retention: str

        :param is_bigfile:
            The value to assign to the is_bigfile property of this TablespaceSummary.
        :type is_bigfile: bool

        :param predicate_evaluation:
            The value to assign to the predicate_evaluation property of this TablespaceSummary.
            Allowed values for this property are: "HOST", "STORAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type predicate_evaluation: str

        :param is_encrypted:
            The value to assign to the is_encrypted property of this TablespaceSummary.
        :type is_encrypted: bool

        :param compress_for:
            The value to assign to the compress_for property of this TablespaceSummary.
            Allowed values for this property are: "BASIC", "ADVANCED", "QUERY_LOW", "QUERY_HIGH", "ARCHIVE_LOW", "ARCHIVE_HIGH", "DIRECT_LOAD_ONLY", "FOR_ALL_OPERATIONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type compress_for: str

        :param default_in_memory:
            The value to assign to the default_in_memory property of this TablespaceSummary.
            Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_in_memory: str

        :param default_in_memory_priority:
            The value to assign to the default_in_memory_priority property of this TablespaceSummary.
            Allowed values for this property are: "LOW", "MEDIUM", "HIGH", "CRITICAL", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_in_memory_priority: str

        :param default_in_memory_distribute:
            The value to assign to the default_in_memory_distribute property of this TablespaceSummary.
            Allowed values for this property are: "AUTO", "BY_ROWID_RANGE", "BY_PARTITION", "BY_SUBPARTITION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_in_memory_distribute: str

        :param default_in_memory_compression:
            The value to assign to the default_in_memory_compression property of this TablespaceSummary.
            Allowed values for this property are: "NO_MEMCOMPRESS", "FOR_DML", "FOR_QUERY_LOW", "FOR_QUERY_HIGH", "FOR_CAPACITY_LOW", "FOR_CAPACITY_HIGH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_in_memory_compression: str

        :param default_in_memory_duplicate:
            The value to assign to the default_in_memory_duplicate property of this TablespaceSummary.
            Allowed values for this property are: "NO_DUPLICATE", "DUPLICATE", "DUPLICATE_ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_in_memory_duplicate: str

        :param shared:
            The value to assign to the shared property of this TablespaceSummary.
            Allowed values for this property are: "SHARED", "LOCAL_ON_LEAF", "LOCAL_ON_ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type shared: str

        :param default_index_compression:
            The value to assign to the default_index_compression property of this TablespaceSummary.
            Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_index_compression: str

        :param index_compress_for:
            The value to assign to the index_compress_for property of this TablespaceSummary.
            Allowed values for this property are: "ADVANCED_LOW", "ADVANCED_HIGH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type index_compress_for: str

        :param default_cell_memory:
            The value to assign to the default_cell_memory property of this TablespaceSummary.
        :type default_cell_memory: str

        :param default_in_memory_service:
            The value to assign to the default_in_memory_service property of this TablespaceSummary.
            Allowed values for this property are: "DEFAULT", "NONE", "ALL", "USER_DEFINED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type default_in_memory_service: str

        :param default_in_memory_service_name:
            The value to assign to the default_in_memory_service_name property of this TablespaceSummary.
        :type default_in_memory_service_name: str

        :param lost_write_protect:
            The value to assign to the lost_write_protect property of this TablespaceSummary.
            Allowed values for this property are: "ENABLED", "PROTECT_OFF", "SUSPEND", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lost_write_protect: str

        :param is_chunk_tablespace:
            The value to assign to the is_chunk_tablespace property of this TablespaceSummary.
        :type is_chunk_tablespace: bool

        :param temp_group:
            The value to assign to the temp_group property of this TablespaceSummary.
        :type temp_group: str

        :param max_size_kb:
            The value to assign to the max_size_kb property of this TablespaceSummary.
        :type max_size_kb: float

        :param allocated_size_kb:
            The value to assign to the allocated_size_kb property of this TablespaceSummary.
        :type allocated_size_kb: float

        :param user_size_kb:
            The value to assign to the user_size_kb property of this TablespaceSummary.
        :type user_size_kb: float

        :param free_space_kb:
            The value to assign to the free_space_kb property of this TablespaceSummary.
        :type free_space_kb: float

        :param used_space_kb:
            The value to assign to the used_space_kb property of this TablespaceSummary.
        :type used_space_kb: float

        :param used_percent_available:
            The value to assign to the used_percent_available property of this TablespaceSummary.
        :type used_percent_available: float

        :param used_percent_allocated:
            The value to assign to the used_percent_allocated property of this TablespaceSummary.
        :type used_percent_allocated: float

        :param datafiles:
            The value to assign to the datafiles property of this TablespaceSummary.
        :type datafiles: list[oci.database_management.models.Datafile]

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'status': 'str',
            'block_size_bytes': 'float',
            'logging': 'str',
            'is_force_logging': 'bool',
            'extent_management': 'str',
            'allocation_type': 'str',
            'is_plugged_in': 'bool',
            'segment_space_management': 'str',
            'default_table_compression': 'str',
            'retention': 'str',
            'is_bigfile': 'bool',
            'predicate_evaluation': 'str',
            'is_encrypted': 'bool',
            'compress_for': 'str',
            'default_in_memory': 'str',
            'default_in_memory_priority': 'str',
            'default_in_memory_distribute': 'str',
            'default_in_memory_compression': 'str',
            'default_in_memory_duplicate': 'str',
            'shared': 'str',
            'default_index_compression': 'str',
            'index_compress_for': 'str',
            'default_cell_memory': 'str',
            'default_in_memory_service': 'str',
            'default_in_memory_service_name': 'str',
            'lost_write_protect': 'str',
            'is_chunk_tablespace': 'bool',
            'temp_group': 'str',
            'max_size_kb': 'float',
            'allocated_size_kb': 'float',
            'user_size_kb': 'float',
            'free_space_kb': 'float',
            'used_space_kb': 'float',
            'used_percent_available': 'float',
            'used_percent_allocated': 'float',
            'datafiles': 'list[Datafile]'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'status': 'status',
            'block_size_bytes': 'blockSizeBytes',
            'logging': 'logging',
            'is_force_logging': 'isForceLogging',
            'extent_management': 'extentManagement',
            'allocation_type': 'allocationType',
            'is_plugged_in': 'isPluggedIn',
            'segment_space_management': 'segmentSpaceManagement',
            'default_table_compression': 'defaultTableCompression',
            'retention': 'retention',
            'is_bigfile': 'isBigfile',
            'predicate_evaluation': 'predicateEvaluation',
            'is_encrypted': 'isEncrypted',
            'compress_for': 'compressFor',
            'default_in_memory': 'defaultInMemory',
            'default_in_memory_priority': 'defaultInMemoryPriority',
            'default_in_memory_distribute': 'defaultInMemoryDistribute',
            'default_in_memory_compression': 'defaultInMemoryCompression',
            'default_in_memory_duplicate': 'defaultInMemoryDuplicate',
            'shared': 'shared',
            'default_index_compression': 'defaultIndexCompression',
            'index_compress_for': 'indexCompressFor',
            'default_cell_memory': 'defaultCellMemory',
            'default_in_memory_service': 'defaultInMemoryService',
            'default_in_memory_service_name': 'defaultInMemoryServiceName',
            'lost_write_protect': 'lostWriteProtect',
            'is_chunk_tablespace': 'isChunkTablespace',
            'temp_group': 'tempGroup',
            'max_size_kb': 'maxSizeKB',
            'allocated_size_kb': 'allocatedSizeKB',
            'user_size_kb': 'userSizeKB',
            'free_space_kb': 'freeSpaceKB',
            'used_space_kb': 'usedSpaceKB',
            'used_percent_available': 'usedPercentAvailable',
            'used_percent_allocated': 'usedPercentAllocated',
            'datafiles': 'datafiles'
        }

        self._name = None
        self._type = None
        self._status = None
        self._block_size_bytes = None
        self._logging = None
        self._is_force_logging = None
        self._extent_management = None
        self._allocation_type = None
        self._is_plugged_in = None
        self._segment_space_management = None
        self._default_table_compression = None
        self._retention = None
        self._is_bigfile = None
        self._predicate_evaluation = None
        self._is_encrypted = None
        self._compress_for = None
        self._default_in_memory = None
        self._default_in_memory_priority = None
        self._default_in_memory_distribute = None
        self._default_in_memory_compression = None
        self._default_in_memory_duplicate = None
        self._shared = None
        self._default_index_compression = None
        self._index_compress_for = None
        self._default_cell_memory = None
        self._default_in_memory_service = None
        self._default_in_memory_service_name = None
        self._lost_write_protect = None
        self._is_chunk_tablespace = None
        self._temp_group = None
        self._max_size_kb = None
        self._allocated_size_kb = None
        self._user_size_kb = None
        self._free_space_kb = None
        self._used_space_kb = None
        self._used_percent_available = None
        self._used_percent_allocated = None
        self._datafiles = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this TablespaceSummary.
        The name of the tablespace.


        :return: The name of this TablespaceSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TablespaceSummary.
        The name of the tablespace.


        :param name: The name of this TablespaceSummary.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this TablespaceSummary.
        The type of the tablespace.

        Allowed values for this property are: "UNDO", "LOST_WRITE_PROTECTION", "PERMANENT", "TEMPORARY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this TablespaceSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TablespaceSummary.
        The type of the tablespace.


        :param type: The type of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["UNDO", "LOST_WRITE_PROTECTION", "PERMANENT", "TEMPORARY"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def status(self):
        """
        Gets the status of this TablespaceSummary.
        The status of the tablespace.

        Allowed values for this property are: "ONLINE", "OFFLINE", "READ_ONLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this TablespaceSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TablespaceSummary.
        The status of the tablespace.


        :param status: The status of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["ONLINE", "OFFLINE", "READ_ONLY"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def block_size_bytes(self):
        """
        Gets the block_size_bytes of this TablespaceSummary.
        The tablespace block size in bytes.


        :return: The block_size_bytes of this TablespaceSummary.
        :rtype: float
        """
        return self._block_size_bytes

    @block_size_bytes.setter
    def block_size_bytes(self, block_size_bytes):
        """
        Sets the block_size_bytes of this TablespaceSummary.
        The tablespace block size in bytes.


        :param block_size_bytes: The block_size_bytes of this TablespaceSummary.
        :type: float
        """
        self._block_size_bytes = block_size_bytes

    @property
    def logging(self):
        """
        Gets the logging of this TablespaceSummary.
        The default logging attribute.

        Allowed values for this property are: "LOGGING", "NOLOGGING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The logging of this TablespaceSummary.
        :rtype: str
        """
        return self._logging

    @logging.setter
    def logging(self, logging):
        """
        Sets the logging of this TablespaceSummary.
        The default logging attribute.


        :param logging: The logging of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["LOGGING", "NOLOGGING"]
        if not value_allowed_none_or_none_sentinel(logging, allowed_values):
            logging = 'UNKNOWN_ENUM_VALUE'
        self._logging = logging

    @property
    def is_force_logging(self):
        """
        Gets the is_force_logging of this TablespaceSummary.
        Indicates whether the tablespace is under Force Logging mode.


        :return: The is_force_logging of this TablespaceSummary.
        :rtype: bool
        """
        return self._is_force_logging

    @is_force_logging.setter
    def is_force_logging(self, is_force_logging):
        """
        Sets the is_force_logging of this TablespaceSummary.
        Indicates whether the tablespace is under Force Logging mode.


        :param is_force_logging: The is_force_logging of this TablespaceSummary.
        :type: bool
        """
        self._is_force_logging = is_force_logging

    @property
    def extent_management(self):
        """
        Gets the extent_management of this TablespaceSummary.
        Indicates whether the extents in the tablespace are Locally managed or Dictionary managed.

        Allowed values for this property are: "LOCAL", "DICTIONARY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The extent_management of this TablespaceSummary.
        :rtype: str
        """
        return self._extent_management

    @extent_management.setter
    def extent_management(self, extent_management):
        """
        Sets the extent_management of this TablespaceSummary.
        Indicates whether the extents in the tablespace are Locally managed or Dictionary managed.


        :param extent_management: The extent_management of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["LOCAL", "DICTIONARY"]
        if not value_allowed_none_or_none_sentinel(extent_management, allowed_values):
            extent_management = 'UNKNOWN_ENUM_VALUE'
        self._extent_management = extent_management

    @property
    def allocation_type(self):
        """
        Gets the allocation_type of this TablespaceSummary.
        The type of extent allocation in effect for the tablespace.

        Allowed values for this property are: "SYSTEM", "UNIFORM", "USER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The allocation_type of this TablespaceSummary.
        :rtype: str
        """
        return self._allocation_type

    @allocation_type.setter
    def allocation_type(self, allocation_type):
        """
        Sets the allocation_type of this TablespaceSummary.
        The type of extent allocation in effect for the tablespace.


        :param allocation_type: The allocation_type of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["SYSTEM", "UNIFORM", "USER"]
        if not value_allowed_none_or_none_sentinel(allocation_type, allowed_values):
            allocation_type = 'UNKNOWN_ENUM_VALUE'
        self._allocation_type = allocation_type

    @property
    def is_plugged_in(self):
        """
        Gets the is_plugged_in of this TablespaceSummary.
        Indicates whether the tablespace is plugged in.


        :return: The is_plugged_in of this TablespaceSummary.
        :rtype: bool
        """
        return self._is_plugged_in

    @is_plugged_in.setter
    def is_plugged_in(self, is_plugged_in):
        """
        Sets the is_plugged_in of this TablespaceSummary.
        Indicates whether the tablespace is plugged in.


        :param is_plugged_in: The is_plugged_in of this TablespaceSummary.
        :type: bool
        """
        self._is_plugged_in = is_plugged_in

    @property
    def segment_space_management(self):
        """
        Gets the segment_space_management of this TablespaceSummary.
        Indicates whether the free and used segment space in the tablespace is managed using free lists (MANUAL) or bitmaps (AUTO).

        Allowed values for this property are: "MANUAL", "AUTO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The segment_space_management of this TablespaceSummary.
        :rtype: str
        """
        return self._segment_space_management

    @segment_space_management.setter
    def segment_space_management(self, segment_space_management):
        """
        Sets the segment_space_management of this TablespaceSummary.
        Indicates whether the free and used segment space in the tablespace is managed using free lists (MANUAL) or bitmaps (AUTO).


        :param segment_space_management: The segment_space_management of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["MANUAL", "AUTO"]
        if not value_allowed_none_or_none_sentinel(segment_space_management, allowed_values):
            segment_space_management = 'UNKNOWN_ENUM_VALUE'
        self._segment_space_management = segment_space_management

    @property
    def default_table_compression(self):
        """
        Gets the default_table_compression of this TablespaceSummary.
        Indicates whether default table compression is enabled or disabled.

        Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_table_compression of this TablespaceSummary.
        :rtype: str
        """
        return self._default_table_compression

    @default_table_compression.setter
    def default_table_compression(self, default_table_compression):
        """
        Sets the default_table_compression of this TablespaceSummary.
        Indicates whether default table compression is enabled or disabled.


        :param default_table_compression: The default_table_compression of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(default_table_compression, allowed_values):
            default_table_compression = 'UNKNOWN_ENUM_VALUE'
        self._default_table_compression = default_table_compression

    @property
    def retention(self):
        """
        Gets the retention of this TablespaceSummary.
        Indicates whether undo retention guarantee is enabled for the tablespace.

        Allowed values for this property are: "GUARANTEE", "NOGUARANTEE", "NOT_APPLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The retention of this TablespaceSummary.
        :rtype: str
        """
        return self._retention

    @retention.setter
    def retention(self, retention):
        """
        Sets the retention of this TablespaceSummary.
        Indicates whether undo retention guarantee is enabled for the tablespace.


        :param retention: The retention of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["GUARANTEE", "NOGUARANTEE", "NOT_APPLY"]
        if not value_allowed_none_or_none_sentinel(retention, allowed_values):
            retention = 'UNKNOWN_ENUM_VALUE'
        self._retention = retention

    @property
    def is_bigfile(self):
        """
        Gets the is_bigfile of this TablespaceSummary.
        Indicates whether the tablespace is a Bigfile tablespace or a Smallfile tablespace.


        :return: The is_bigfile of this TablespaceSummary.
        :rtype: bool
        """
        return self._is_bigfile

    @is_bigfile.setter
    def is_bigfile(self, is_bigfile):
        """
        Sets the is_bigfile of this TablespaceSummary.
        Indicates whether the tablespace is a Bigfile tablespace or a Smallfile tablespace.


        :param is_bigfile: The is_bigfile of this TablespaceSummary.
        :type: bool
        """
        self._is_bigfile = is_bigfile

    @property
    def predicate_evaluation(self):
        """
        Gets the predicate_evaluation of this TablespaceSummary.
        Indicates whether predicates are evaluated by Host or by Storage.

        Allowed values for this property are: "HOST", "STORAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The predicate_evaluation of this TablespaceSummary.
        :rtype: str
        """
        return self._predicate_evaluation

    @predicate_evaluation.setter
    def predicate_evaluation(self, predicate_evaluation):
        """
        Sets the predicate_evaluation of this TablespaceSummary.
        Indicates whether predicates are evaluated by Host or by Storage.


        :param predicate_evaluation: The predicate_evaluation of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["HOST", "STORAGE"]
        if not value_allowed_none_or_none_sentinel(predicate_evaluation, allowed_values):
            predicate_evaluation = 'UNKNOWN_ENUM_VALUE'
        self._predicate_evaluation = predicate_evaluation

    @property
    def is_encrypted(self):
        """
        Gets the is_encrypted of this TablespaceSummary.
        Indicates whether the tablespace is encrypted.


        :return: The is_encrypted of this TablespaceSummary.
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """
        Sets the is_encrypted of this TablespaceSummary.
        Indicates whether the tablespace is encrypted.


        :param is_encrypted: The is_encrypted of this TablespaceSummary.
        :type: bool
        """
        self._is_encrypted = is_encrypted

    @property
    def compress_for(self):
        """
        Gets the compress_for of this TablespaceSummary.
        The operation type for which default compression is enabled.

        Allowed values for this property are: "BASIC", "ADVANCED", "QUERY_LOW", "QUERY_HIGH", "ARCHIVE_LOW", "ARCHIVE_HIGH", "DIRECT_LOAD_ONLY", "FOR_ALL_OPERATIONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The compress_for of this TablespaceSummary.
        :rtype: str
        """
        return self._compress_for

    @compress_for.setter
    def compress_for(self, compress_for):
        """
        Sets the compress_for of this TablespaceSummary.
        The operation type for which default compression is enabled.


        :param compress_for: The compress_for of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["BASIC", "ADVANCED", "QUERY_LOW", "QUERY_HIGH", "ARCHIVE_LOW", "ARCHIVE_HIGH", "DIRECT_LOAD_ONLY", "FOR_ALL_OPERATIONS"]
        if not value_allowed_none_or_none_sentinel(compress_for, allowed_values):
            compress_for = 'UNKNOWN_ENUM_VALUE'
        self._compress_for = compress_for

    @property
    def default_in_memory(self):
        """
        Gets the default_in_memory of this TablespaceSummary.
        Indicates whether the In-Memory Column Store (IM column store) is by default enabled or disabled for tables in this tablespace.

        Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_in_memory of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory

    @default_in_memory.setter
    def default_in_memory(self, default_in_memory):
        """
        Sets the default_in_memory of this TablespaceSummary.
        Indicates whether the In-Memory Column Store (IM column store) is by default enabled or disabled for tables in this tablespace.


        :param default_in_memory: The default_in_memory of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(default_in_memory, allowed_values):
            default_in_memory = 'UNKNOWN_ENUM_VALUE'
        self._default_in_memory = default_in_memory

    @property
    def default_in_memory_priority(self):
        """
        Gets the default_in_memory_priority of this TablespaceSummary.
        Indicates the default priority for In-Memory Column Store (IM column store) population for this tablespace.

        Allowed values for this property are: "LOW", "MEDIUM", "HIGH", "CRITICAL", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_in_memory_priority of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory_priority

    @default_in_memory_priority.setter
    def default_in_memory_priority(self, default_in_memory_priority):
        """
        Sets the default_in_memory_priority of this TablespaceSummary.
        Indicates the default priority for In-Memory Column Store (IM column store) population for this tablespace.


        :param default_in_memory_priority: The default_in_memory_priority of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL", "NONE"]
        if not value_allowed_none_or_none_sentinel(default_in_memory_priority, allowed_values):
            default_in_memory_priority = 'UNKNOWN_ENUM_VALUE'
        self._default_in_memory_priority = default_in_memory_priority

    @property
    def default_in_memory_distribute(self):
        """
        Gets the default_in_memory_distribute of this TablespaceSummary.
        Indicates how the IM column store is distributed by default for this tablespace in an Oracle Real Application Clusters (Oracle RAC) environment.

        Allowed values for this property are: "AUTO", "BY_ROWID_RANGE", "BY_PARTITION", "BY_SUBPARTITION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_in_memory_distribute of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory_distribute

    @default_in_memory_distribute.setter
    def default_in_memory_distribute(self, default_in_memory_distribute):
        """
        Sets the default_in_memory_distribute of this TablespaceSummary.
        Indicates how the IM column store is distributed by default for this tablespace in an Oracle Real Application Clusters (Oracle RAC) environment.


        :param default_in_memory_distribute: The default_in_memory_distribute of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["AUTO", "BY_ROWID_RANGE", "BY_PARTITION", "BY_SUBPARTITION"]
        if not value_allowed_none_or_none_sentinel(default_in_memory_distribute, allowed_values):
            default_in_memory_distribute = 'UNKNOWN_ENUM_VALUE'
        self._default_in_memory_distribute = default_in_memory_distribute

    @property
    def default_in_memory_compression(self):
        """
        Gets the default_in_memory_compression of this TablespaceSummary.
        Indicates the default compression level for the IM column store for this tablespace.

        Allowed values for this property are: "NO_MEMCOMPRESS", "FOR_DML", "FOR_QUERY_LOW", "FOR_QUERY_HIGH", "FOR_CAPACITY_LOW", "FOR_CAPACITY_HIGH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_in_memory_compression of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory_compression

    @default_in_memory_compression.setter
    def default_in_memory_compression(self, default_in_memory_compression):
        """
        Sets the default_in_memory_compression of this TablespaceSummary.
        Indicates the default compression level for the IM column store for this tablespace.


        :param default_in_memory_compression: The default_in_memory_compression of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["NO_MEMCOMPRESS", "FOR_DML", "FOR_QUERY_LOW", "FOR_QUERY_HIGH", "FOR_CAPACITY_LOW", "FOR_CAPACITY_HIGH"]
        if not value_allowed_none_or_none_sentinel(default_in_memory_compression, allowed_values):
            default_in_memory_compression = 'UNKNOWN_ENUM_VALUE'
        self._default_in_memory_compression = default_in_memory_compression

    @property
    def default_in_memory_duplicate(self):
        """
        Gets the default_in_memory_duplicate of this TablespaceSummary.
        Indicates the duplicate setting for the IM column store in an Oracle RAC environment.

        Allowed values for this property are: "NO_DUPLICATE", "DUPLICATE", "DUPLICATE_ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_in_memory_duplicate of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory_duplicate

    @default_in_memory_duplicate.setter
    def default_in_memory_duplicate(self, default_in_memory_duplicate):
        """
        Sets the default_in_memory_duplicate of this TablespaceSummary.
        Indicates the duplicate setting for the IM column store in an Oracle RAC environment.


        :param default_in_memory_duplicate: The default_in_memory_duplicate of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["NO_DUPLICATE", "DUPLICATE", "DUPLICATE_ALL"]
        if not value_allowed_none_or_none_sentinel(default_in_memory_duplicate, allowed_values):
            default_in_memory_duplicate = 'UNKNOWN_ENUM_VALUE'
        self._default_in_memory_duplicate = default_in_memory_duplicate

    @property
    def shared(self):
        """
        Gets the shared of this TablespaceSummary.
        Indicates whether the tablespace is for shared tablespace, or for local temporary tablespace for leaf (read-only) instances, or for local temporary tablespace for all instance types.

        Allowed values for this property are: "SHARED", "LOCAL_ON_LEAF", "LOCAL_ON_ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The shared of this TablespaceSummary.
        :rtype: str
        """
        return self._shared

    @shared.setter
    def shared(self, shared):
        """
        Sets the shared of this TablespaceSummary.
        Indicates whether the tablespace is for shared tablespace, or for local temporary tablespace for leaf (read-only) instances, or for local temporary tablespace for all instance types.


        :param shared: The shared of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["SHARED", "LOCAL_ON_LEAF", "LOCAL_ON_ALL"]
        if not value_allowed_none_or_none_sentinel(shared, allowed_values):
            shared = 'UNKNOWN_ENUM_VALUE'
        self._shared = shared

    @property
    def default_index_compression(self):
        """
        Gets the default_index_compression of this TablespaceSummary.
        Indicates whether default index compression is enabled or disabled.

        Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_index_compression of this TablespaceSummary.
        :rtype: str
        """
        return self._default_index_compression

    @default_index_compression.setter
    def default_index_compression(self, default_index_compression):
        """
        Sets the default_index_compression of this TablespaceSummary.
        Indicates whether default index compression is enabled or disabled.


        :param default_index_compression: The default_index_compression of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(default_index_compression, allowed_values):
            default_index_compression = 'UNKNOWN_ENUM_VALUE'
        self._default_index_compression = default_index_compression

    @property
    def index_compress_for(self):
        """
        Gets the index_compress_for of this TablespaceSummary.
        The operation type for which default index compression is enabled.

        Allowed values for this property are: "ADVANCED_LOW", "ADVANCED_HIGH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The index_compress_for of this TablespaceSummary.
        :rtype: str
        """
        return self._index_compress_for

    @index_compress_for.setter
    def index_compress_for(self, index_compress_for):
        """
        Sets the index_compress_for of this TablespaceSummary.
        The operation type for which default index compression is enabled.


        :param index_compress_for: The index_compress_for of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["ADVANCED_LOW", "ADVANCED_HIGH"]
        if not value_allowed_none_or_none_sentinel(index_compress_for, allowed_values):
            index_compress_for = 'UNKNOWN_ENUM_VALUE'
        self._index_compress_for = index_compress_for

    @property
    def default_cell_memory(self):
        """
        Gets the default_cell_memory of this TablespaceSummary.
        This specifies the default value for the CELLMEMORY attribute that tables created in the tablespace will inherit unless the behavior is overridden explicitly. This column is intended for use with Oracle Exadata.


        :return: The default_cell_memory of this TablespaceSummary.
        :rtype: str
        """
        return self._default_cell_memory

    @default_cell_memory.setter
    def default_cell_memory(self, default_cell_memory):
        """
        Sets the default_cell_memory of this TablespaceSummary.
        This specifies the default value for the CELLMEMORY attribute that tables created in the tablespace will inherit unless the behavior is overridden explicitly. This column is intended for use with Oracle Exadata.


        :param default_cell_memory: The default_cell_memory of this TablespaceSummary.
        :type: str
        """
        self._default_cell_memory = default_cell_memory

    @property
    def default_in_memory_service(self):
        """
        Gets the default_in_memory_service of this TablespaceSummary.
        Indicates how the IM column store is populated on various instances by default for this tablespace.

        Allowed values for this property are: "DEFAULT", "NONE", "ALL", "USER_DEFINED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The default_in_memory_service of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory_service

    @default_in_memory_service.setter
    def default_in_memory_service(self, default_in_memory_service):
        """
        Sets the default_in_memory_service of this TablespaceSummary.
        Indicates how the IM column store is populated on various instances by default for this tablespace.


        :param default_in_memory_service: The default_in_memory_service of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["DEFAULT", "NONE", "ALL", "USER_DEFINED"]
        if not value_allowed_none_or_none_sentinel(default_in_memory_service, allowed_values):
            default_in_memory_service = 'UNKNOWN_ENUM_VALUE'
        self._default_in_memory_service = default_in_memory_service

    @property
    def default_in_memory_service_name(self):
        """
        Gets the default_in_memory_service_name of this TablespaceSummary.
        Indicates the service name for the service on which the IM column store should be populated by default for this tablespace. This column has a value only when the corresponding DEF_INMEMORY_SERVICE is USER_DEFINED. In all other cases, this column is null.


        :return: The default_in_memory_service_name of this TablespaceSummary.
        :rtype: str
        """
        return self._default_in_memory_service_name

    @default_in_memory_service_name.setter
    def default_in_memory_service_name(self, default_in_memory_service_name):
        """
        Sets the default_in_memory_service_name of this TablespaceSummary.
        Indicates the service name for the service on which the IM column store should be populated by default for this tablespace. This column has a value only when the corresponding DEF_INMEMORY_SERVICE is USER_DEFINED. In all other cases, this column is null.


        :param default_in_memory_service_name: The default_in_memory_service_name of this TablespaceSummary.
        :type: str
        """
        self._default_in_memory_service_name = default_in_memory_service_name

    @property
    def lost_write_protect(self):
        """
        Gets the lost_write_protect of this TablespaceSummary.
        The lost write protection setting for the tablespace.

        Allowed values for this property are: "ENABLED", "PROTECT_OFF", "SUSPEND", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lost_write_protect of this TablespaceSummary.
        :rtype: str
        """
        return self._lost_write_protect

    @lost_write_protect.setter
    def lost_write_protect(self, lost_write_protect):
        """
        Sets the lost_write_protect of this TablespaceSummary.
        The lost write protection setting for the tablespace.


        :param lost_write_protect: The lost_write_protect of this TablespaceSummary.
        :type: str
        """
        allowed_values = ["ENABLED", "PROTECT_OFF", "SUSPEND"]
        if not value_allowed_none_or_none_sentinel(lost_write_protect, allowed_values):
            lost_write_protect = 'UNKNOWN_ENUM_VALUE'
        self._lost_write_protect = lost_write_protect

    @property
    def is_chunk_tablespace(self):
        """
        Gets the is_chunk_tablespace of this TablespaceSummary.
        Indicates whether this is a chunk tablespace.


        :return: The is_chunk_tablespace of this TablespaceSummary.
        :rtype: bool
        """
        return self._is_chunk_tablespace

    @is_chunk_tablespace.setter
    def is_chunk_tablespace(self, is_chunk_tablespace):
        """
        Sets the is_chunk_tablespace of this TablespaceSummary.
        Indicates whether this is a chunk tablespace.


        :param is_chunk_tablespace: The is_chunk_tablespace of this TablespaceSummary.
        :type: bool
        """
        self._is_chunk_tablespace = is_chunk_tablespace

    @property
    def temp_group(self):
        """
        Gets the temp_group of this TablespaceSummary.
        The temporary tablespace group.


        :return: The temp_group of this TablespaceSummary.
        :rtype: str
        """
        return self._temp_group

    @temp_group.setter
    def temp_group(self, temp_group):
        """
        Sets the temp_group of this TablespaceSummary.
        The temporary tablespace group.


        :param temp_group: The temp_group of this TablespaceSummary.
        :type: str
        """
        self._temp_group = temp_group

    @property
    def max_size_kb(self):
        """
        Gets the max_size_kb of this TablespaceSummary.
        The maximum tablespace size in KB. If the tablespace contains any datafiles with Autoextend enabled, then this column displays the amount of underlying free storage space for the tablespace. For example, if the current tablespace size is 1 GB, the combined maximum size of all its datafiles is 32 GB, and its underlying storage (for example, ASM or file system storage) has 20 GB of free space, then this column will have a value of approximately 20 GB. If the tablespace contains only datafiles with autoextend disabled, then this column displays the allocated space for the entire tablespace, that is, the combined size of all datafiles in the tablespace.


        :return: The max_size_kb of this TablespaceSummary.
        :rtype: float
        """
        return self._max_size_kb

    @max_size_kb.setter
    def max_size_kb(self, max_size_kb):
        """
        Sets the max_size_kb of this TablespaceSummary.
        The maximum tablespace size in KB. If the tablespace contains any datafiles with Autoextend enabled, then this column displays the amount of underlying free storage space for the tablespace. For example, if the current tablespace size is 1 GB, the combined maximum size of all its datafiles is 32 GB, and its underlying storage (for example, ASM or file system storage) has 20 GB of free space, then this column will have a value of approximately 20 GB. If the tablespace contains only datafiles with autoextend disabled, then this column displays the allocated space for the entire tablespace, that is, the combined size of all datafiles in the tablespace.


        :param max_size_kb: The max_size_kb of this TablespaceSummary.
        :type: float
        """
        self._max_size_kb = max_size_kb

    @property
    def allocated_size_kb(self):
        """
        Gets the allocated_size_kb of this TablespaceSummary.
        The allocated tablespace size in KB.


        :return: The allocated_size_kb of this TablespaceSummary.
        :rtype: float
        """
        return self._allocated_size_kb

    @allocated_size_kb.setter
    def allocated_size_kb(self, allocated_size_kb):
        """
        Sets the allocated_size_kb of this TablespaceSummary.
        The allocated tablespace size in KB.


        :param allocated_size_kb: The allocated_size_kb of this TablespaceSummary.
        :type: float
        """
        self._allocated_size_kb = allocated_size_kb

    @property
    def user_size_kb(self):
        """
        Gets the user_size_kb of this TablespaceSummary.
        The size of the tablespace available for user data in KB. The difference between tablespace size and user data size is used for storing metadata.


        :return: The user_size_kb of this TablespaceSummary.
        :rtype: float
        """
        return self._user_size_kb

    @user_size_kb.setter
    def user_size_kb(self, user_size_kb):
        """
        Sets the user_size_kb of this TablespaceSummary.
        The size of the tablespace available for user data in KB. The difference between tablespace size and user data size is used for storing metadata.


        :param user_size_kb: The user_size_kb of this TablespaceSummary.
        :type: float
        """
        self._user_size_kb = user_size_kb

    @property
    def free_space_kb(self):
        """
        Gets the free_space_kb of this TablespaceSummary.
        The free space available in this tablespace in KB.


        :return: The free_space_kb of this TablespaceSummary.
        :rtype: float
        """
        return self._free_space_kb

    @free_space_kb.setter
    def free_space_kb(self, free_space_kb):
        """
        Sets the free_space_kb of this TablespaceSummary.
        The free space available in this tablespace in KB.


        :param free_space_kb: The free_space_kb of this TablespaceSummary.
        :type: float
        """
        self._free_space_kb = free_space_kb

    @property
    def used_space_kb(self):
        """
        Gets the used_space_kb of this TablespaceSummary.
        The total space used by the tablespace in KB.


        :return: The used_space_kb of this TablespaceSummary.
        :rtype: float
        """
        return self._used_space_kb

    @used_space_kb.setter
    def used_space_kb(self, used_space_kb):
        """
        Sets the used_space_kb of this TablespaceSummary.
        The total space used by the tablespace in KB.


        :param used_space_kb: The used_space_kb of this TablespaceSummary.
        :type: float
        """
        self._used_space_kb = used_space_kb

    @property
    def used_percent_available(self):
        """
        Gets the used_percent_available of this TablespaceSummary.
        The percentage of used space out of the maximum available space in the tablespace.


        :return: The used_percent_available of this TablespaceSummary.
        :rtype: float
        """
        return self._used_percent_available

    @used_percent_available.setter
    def used_percent_available(self, used_percent_available):
        """
        Sets the used_percent_available of this TablespaceSummary.
        The percentage of used space out of the maximum available space in the tablespace.


        :param used_percent_available: The used_percent_available of this TablespaceSummary.
        :type: float
        """
        self._used_percent_available = used_percent_available

    @property
    def used_percent_allocated(self):
        """
        Gets the used_percent_allocated of this TablespaceSummary.
        The percentage of used space out of the total allocated space in the tablespace.


        :return: The used_percent_allocated of this TablespaceSummary.
        :rtype: float
        """
        return self._used_percent_allocated

    @used_percent_allocated.setter
    def used_percent_allocated(self, used_percent_allocated):
        """
        Sets the used_percent_allocated of this TablespaceSummary.
        The percentage of used space out of the total allocated space in the tablespace.


        :param used_percent_allocated: The used_percent_allocated of this TablespaceSummary.
        :type: float
        """
        self._used_percent_allocated = used_percent_allocated

    @property
    def datafiles(self):
        """
        Gets the datafiles of this TablespaceSummary.
        A list of the datafiles associated with the tablespace.


        :return: The datafiles of this TablespaceSummary.
        :rtype: list[oci.database_management.models.Datafile]
        """
        return self._datafiles

    @datafiles.setter
    def datafiles(self, datafiles):
        """
        Sets the datafiles of this TablespaceSummary.
        A list of the datafiles associated with the tablespace.


        :param datafiles: The datafiles of this TablespaceSummary.
        :type: list[oci.database_management.models.Datafile]
        """
        self._datafiles = datafiles

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Contact(object):
    """
    Contact details for the customer.
    """

    #: A constant which can be used with the contact_type property of a Contact.
    #: This constant has a value of "PRIMARY"
    CONTACT_TYPE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the contact_type property of a Contact.
    #: This constant has a value of "ALTERNATE"
    CONTACT_TYPE_ALTERNATE = "ALTERNATE"

    #: A constant which can be used with the contact_type property of a Contact.
    #: This constant has a value of "SECONDARY"
    CONTACT_TYPE_SECONDARY = "SECONDARY"

    #: A constant which can be used with the contact_type property of a Contact.
    #: This constant has a value of "ADMIN"
    CONTACT_TYPE_ADMIN = "ADMIN"

    #: A constant which can be used with the contact_type property of a Contact.
    #: This constant has a value of "MANAGER"
    CONTACT_TYPE_MANAGER = "MANAGER"

    def __init__(self, **kwargs):
        """
        Initializes a new Contact object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param contact_name:
            The value to assign to the contact_name property of this Contact.
        :type contact_name: str

        :param contact_email:
            The value to assign to the contact_email property of this Contact.
        :type contact_email: str

        :param contact_phone:
            The value to assign to the contact_phone property of this Contact.
        :type contact_phone: str

        :param contact_type:
            The value to assign to the contact_type property of this Contact.
            Allowed values for this property are: "PRIMARY", "ALTERNATE", "SECONDARY", "ADMIN", "MANAGER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type contact_type: str

        """
        self.swagger_types = {
            'contact_name': 'str',
            'contact_email': 'str',
            'contact_phone': 'str',
            'contact_type': 'str'
        }

        self.attribute_map = {
            'contact_name': 'contactName',
            'contact_email': 'contactEmail',
            'contact_phone': 'contactPhone',
            'contact_type': 'contactType'
        }

        self._contact_name = None
        self._contact_email = None
        self._contact_phone = None
        self._contact_type = None

    @property
    def contact_name(self):
        """
        Gets the contact_name of this Contact.
        The name of the contact person.


        :return: The contact_name of this Contact.
        :rtype: str
        """
        return self._contact_name

    @contact_name.setter
    def contact_name(self, contact_name):
        """
        Sets the contact_name of this Contact.
        The name of the contact person.


        :param contact_name: The contact_name of this Contact.
        :type: str
        """
        self._contact_name = contact_name

    @property
    def contact_email(self):
        """
        Gets the contact_email of this Contact.
        The email of the contact person.


        :return: The contact_email of this Contact.
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """
        Sets the contact_email of this Contact.
        The email of the contact person.


        :param contact_email: The contact_email of this Contact.
        :type: str
        """
        self._contact_email = contact_email

    @property
    def contact_phone(self):
        """
        Gets the contact_phone of this Contact.
        The phone number of the contact person.


        :return: The contact_phone of this Contact.
        :rtype: str
        """
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, contact_phone):
        """
        Sets the contact_phone of this Contact.
        The phone number of the contact person.


        :param contact_phone: The contact_phone of this Contact.
        :type: str
        """
        self._contact_phone = contact_phone

    @property
    def contact_type(self):
        """
        Gets the contact_type of this Contact.
        The type of contact, such as primary or alternate.

        Allowed values for this property are: "PRIMARY", "ALTERNATE", "SECONDARY", "ADMIN", "MANAGER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The contact_type of this Contact.
        :rtype: str
        """
        return self._contact_type

    @contact_type.setter
    def contact_type(self, contact_type):
        """
        Sets the contact_type of this Contact.
        The type of contact, such as primary or alternate.


        :param contact_type: The contact_type of this Contact.
        :type: str
        """
        allowed_values = ["PRIMARY", "ALTERNATE", "SECONDARY", "ADMIN", "MANAGER"]
        if not value_allowed_none_or_none_sentinel(contact_type, allowed_values):
            contact_type = 'UNKNOWN_ENUM_VALUE'
        self._contact_type = contact_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

SERVICE_ENDPOINTS = {
    "announcement": "https://announcements.{domain}",
    "announcements_preferences": "https://announcements.{domain}",
    "audit": "https://audit.{domain}",
    "auto_scaling": "None",
    "blockstorage": "https://iaas.{domain}",
    "budget": "https://iaas.{domain}",
    "compute": "https://iaas.{domain}",
    "compute_management": "https://iaas.{domain}",
    "container_engine": "https://containerengine.{domain}",
    "database": "https://database.{domain}",
    "dns": "https://dns.{domain}",
    "email": "https://email.{domain}",
    "file_storage": "https://filestorage.{domain}",
    "health_checks": "https://healthchecks.{domain}",
    "identity": "https://identity.{domain}",
    "kms_crypto": "https://kms.{domain}",
    "kms_management": "https://kms.{domain}",
    "kms_vault": "https://kms.{domain}",
    "load_balancer": "https://iaas.{domain}",
    "monitoring": "https://telemetry.{domain}",
    "notification_control_plane": "https://notification.{domain}",
    "notification_data_plane": "https://notification.{domain}",
    "object_storage": "https://objectstorage.{domain}",
    "redirect": "https://waas.{domain}",
    "resource_manager": "https://resourcemanager.{domain}",
    "resource_search": "https://query.{domain}",
    "stream": "https://streams.{domain}",
    "stream_admin": "https://streams.{domain}",
    "virtual_network": "https://iaas.{domain}",
    "waas": "https://waas.{domain}"
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterCacheMetric(object):
    """
    The response containing the cluster cache metrics for the
    Oracle Real Application Clusters (Oracle RAC) database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterCacheMetric object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cluster_cache_metrics:
            The value to assign to the cluster_cache_metrics property of this ClusterCacheMetric.
        :type cluster_cache_metrics: list[oci.database_management.models.TimeSeriesMetricDefinition]

        """
        self.swagger_types = {
            'cluster_cache_metrics': 'list[TimeSeriesMetricDefinition]'
        }

        self.attribute_map = {
            'cluster_cache_metrics': 'clusterCacheMetrics'
        }

        self._cluster_cache_metrics = None

    @property
    def cluster_cache_metrics(self):
        """
        **[Required]** Gets the cluster_cache_metrics of this ClusterCacheMetric.
        A list of cluster cache metrics for a specific database.


        :return: The cluster_cache_metrics of this ClusterCacheMetric.
        :rtype: list[oci.database_management.models.TimeSeriesMetricDefinition]
        """
        return self._cluster_cache_metrics

    @cluster_cache_metrics.setter
    def cluster_cache_metrics(self, cluster_cache_metrics):
        """
        Sets the cluster_cache_metrics of this ClusterCacheMetric.
        A list of cluster cache metrics for a specific database.


        :param cluster_cache_metrics: The cluster_cache_metrics of this ClusterCacheMetric.
        :type: list[oci.database_management.models.TimeSeriesMetricDefinition]
        """
        self._cluster_cache_metrics = cluster_cache_metrics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenericArtifactSummary(object):
    """
    Summary information for an artifact.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenericArtifactSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this GenericArtifactSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this GenericArtifactSummary.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this GenericArtifactSummary.
        :type compartment_id: str

        :param repository_id:
            The value to assign to the repository_id property of this GenericArtifactSummary.
        :type repository_id: str

        :param artifact_path:
            The value to assign to the artifact_path property of this GenericArtifactSummary.
        :type artifact_path: str

        :param version:
            The value to assign to the version property of this GenericArtifactSummary.
        :type version: str

        :param sha256:
            The value to assign to the sha256 property of this GenericArtifactSummary.
        :type sha256: str

        :param size_in_bytes:
            The value to assign to the size_in_bytes property of this GenericArtifactSummary.
        :type size_in_bytes: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this GenericArtifactSummary.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this GenericArtifactSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this GenericArtifactSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param time_created:
            The value to assign to the time_created property of this GenericArtifactSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'repository_id': 'str',
            'artifact_path': 'str',
            'version': 'str',
            'sha256': 'str',
            'size_in_bytes': 'int',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'repository_id': 'repositoryId',
            'artifact_path': 'artifactPath',
            'version': 'version',
            'sha256': 'sha256',
            'size_in_bytes': 'sizeInBytes',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'time_created': 'timeCreated'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._repository_id = None
        self._artifact_path = None
        self._version = None
        self._sha256 = None
        self._size_in_bytes = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._time_created = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this GenericArtifactSummary.
        The `OCID`__ of the artifact.

        Example: `ocid1.genericartifact.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this GenericArtifactSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this GenericArtifactSummary.
        The `OCID`__ of the artifact.

        Example: `ocid1.genericartifact.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this GenericArtifactSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this GenericArtifactSummary.
        The artifact name with the format of `<artifact-path>:<artifact-version>`. The artifact name is truncated to a maximum length of 255.

        Example: `project01/my-web-app/artifact-abc:1.0.0`


        :return: The display_name of this GenericArtifactSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this GenericArtifactSummary.
        The artifact name with the format of `<artifact-path>:<artifact-version>`. The artifact name is truncated to a maximum length of 255.

        Example: `project01/my-web-app/artifact-abc:1.0.0`


        :param display_name: The display_name of this GenericArtifactSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this GenericArtifactSummary.
        The OCID of the artifact's compartment.


        :return: The compartment_id of this GenericArtifactSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this GenericArtifactSummary.
        The OCID of the artifact's compartment.


        :param compartment_id: The compartment_id of this GenericArtifactSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def repository_id(self):
        """
        **[Required]** Gets the repository_id of this GenericArtifactSummary.
        The `OCID`__ of the repository.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The repository_id of this GenericArtifactSummary.
        :rtype: str
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """
        Sets the repository_id of this GenericArtifactSummary.
        The `OCID`__ of the repository.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param repository_id: The repository_id of this GenericArtifactSummary.
        :type: str
        """
        self._repository_id = repository_id

    @property
    def artifact_path(self):
        """
        **[Required]** Gets the artifact_path of this GenericArtifactSummary.
        A user-defined path to describe the location of an artifact. Slashes do not create a directory structure, but you can use slashes to organize the repository. An artifact path does not include an artifact version.

        Example: `project01/my-web-app/artifact-abc`


        :return: The artifact_path of this GenericArtifactSummary.
        :rtype: str
        """
        return self._artifact_path

    @artifact_path.setter
    def artifact_path(self, artifact_path):
        """
        Sets the artifact_path of this GenericArtifactSummary.
        A user-defined path to describe the location of an artifact. Slashes do not create a directory structure, but you can use slashes to organize the repository. An artifact path does not include an artifact version.

        Example: `project01/my-web-app/artifact-abc`


        :param artifact_path: The artifact_path of this GenericArtifactSummary.
        :type: str
        """
        self._artifact_path = artifact_path

    @property
    def version(self):
        """
        **[Required]** Gets the version of this GenericArtifactSummary.
        A user-defined string to describe the artifact version.

        Example: `1.1.0` or `1.2-beta-2`


        :return: The version of this GenericArtifactSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this GenericArtifactSummary.
        A user-defined string to describe the artifact version.

        Example: `1.1.0` or `1.2-beta-2`


        :param version: The version of this GenericArtifactSummary.
        :type: str
        """
        self._version = version

    @property
    def sha256(self):
        """
        **[Required]** Gets the sha256 of this GenericArtifactSummary.
        The SHA256 digest for the artifact. When you upload an artifact to the repository, a SHA256 digest is calculated and added to the artifact properties.


        :return: The sha256 of this GenericArtifactSummary.
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """
        Sets the sha256 of this GenericArtifactSummary.
        The SHA256 digest for the artifact. When you upload an artifact to the repository, a SHA256 digest is calculated and added to the artifact properties.


        :param sha256: The sha256 of this GenericArtifactSummary.
        :type: str
        """
        self._sha256 = sha256

    @property
    def size_in_bytes(self):
        """
        **[Required]** Gets the size_in_bytes of this GenericArtifactSummary.
        The size of the artifact in bytes.


        :return: The size_in_bytes of this GenericArtifactSummary.
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """
        Sets the size_in_bytes of this GenericArtifactSummary.
        The size of the artifact in bytes.


        :param size_in_bytes: The size_in_bytes of this GenericArtifactSummary.
        :type: int
        """
        self._size_in_bytes = size_in_bytes

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this GenericArtifactSummary.
        The current state of the generic artifact.


        :return: The lifecycle_state of this GenericArtifactSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this GenericArtifactSummary.
        The current state of the generic artifact.


        :param lifecycle_state: The lifecycle_state of this GenericArtifactSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this GenericArtifactSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this GenericArtifactSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this GenericArtifactSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this GenericArtifactSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this GenericArtifactSummary.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this GenericArtifactSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this GenericArtifactSummary.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this GenericArtifactSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this GenericArtifactSummary.
        An RFC 3339 timestamp indicating when the artifact was created.


        :return: The time_created of this GenericArtifactSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this GenericArtifactSummary.
        An RFC 3339 timestamp indicating when the artifact was created.


        :param time_created: The time_created of this GenericArtifactSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateDataKeyDetails(object):
    """
    Details of the Data Key to be generated.
    """

    #: A constant which can be used with the type property of a GenerateDataKeyDetails.
    #: This constant has a value of "PRIVATE"
    TYPE_PRIVATE = "PRIVATE"

    #: A constant which can be used with the type property of a GenerateDataKeyDetails.
    #: This constant has a value of "PUBLIC"
    TYPE_PUBLIC = "PUBLIC"

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateDataKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this GenerateDataKeyDetails.
        :type name: str

        :param type:
            The value to assign to the type property of this GenerateDataKeyDetails.
            Allowed values for this property are: "PRIVATE", "PUBLIC"
        :type type: str

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type'
        }

        self._name = None
        self._type = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this GenerateDataKeyDetails.
        Name of the Data Key. The name uniquely identifies a Data Key within an APM domain.


        :return: The name of this GenerateDataKeyDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this GenerateDataKeyDetails.
        Name of the Data Key. The name uniquely identifies a Data Key within an APM domain.


        :param name: The name of this GenerateDataKeyDetails.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this GenerateDataKeyDetails.
        Type of the Data Key.

        Allowed values for this property are: "PRIVATE", "PUBLIC"


        :return: The type of this GenerateDataKeyDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this GenerateDataKeyDetails.
        Type of the Data Key.


        :param type: The type of this GenerateDataKeyDetails.
        :type: str
        """
        allowed_values = ["PRIVATE", "PUBLIC"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FacetedSearchFilterRequest(object):
    """
    Object with details about filter criteria.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FacetedSearchFilterRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param search_date_filters:
            The value to assign to the search_date_filters property of this FacetedSearchFilterRequest.
        :type search_date_filters: list[oci.data_catalog.models.FacetedSearchDateFilterRequest]

        :param search_string_filters:
            The value to assign to the search_string_filters property of this FacetedSearchFilterRequest.
        :type search_string_filters: list[oci.data_catalog.models.FacetedSearchStringFilterRequest]

        """
        self.swagger_types = {
            'search_date_filters': 'list[FacetedSearchDateFilterRequest]',
            'search_string_filters': 'list[FacetedSearchStringFilterRequest]'
        }

        self.attribute_map = {
            'search_date_filters': 'searchDateFilters',
            'search_string_filters': 'searchStringFilters'
        }

        self._search_date_filters = None
        self._search_string_filters = None

    @property
    def search_date_filters(self):
        """
        Gets the search_date_filters of this FacetedSearchFilterRequest.
        Object with date filter criteria


        :return: The search_date_filters of this FacetedSearchFilterRequest.
        :rtype: list[oci.data_catalog.models.FacetedSearchDateFilterRequest]
        """
        return self._search_date_filters

    @search_date_filters.setter
    def search_date_filters(self, search_date_filters):
        """
        Sets the search_date_filters of this FacetedSearchFilterRequest.
        Object with date filter criteria


        :param search_date_filters: The search_date_filters of this FacetedSearchFilterRequest.
        :type: list[oci.data_catalog.models.FacetedSearchDateFilterRequest]
        """
        self._search_date_filters = search_date_filters

    @property
    def search_string_filters(self):
        """
        Gets the search_string_filters of this FacetedSearchFilterRequest.
        Object with string filter criteria


        :return: The search_string_filters of this FacetedSearchFilterRequest.
        :rtype: list[oci.data_catalog.models.FacetedSearchStringFilterRequest]
        """
        return self._search_string_filters

    @search_string_filters.setter
    def search_string_filters(self, search_string_filters):
        """
        Sets the search_string_filters of this FacetedSearchFilterRequest.
        Object with string filter criteria


        :param search_string_filters: The search_string_filters of this FacetedSearchFilterRequest.
        :type: list[oci.data_catalog.models.FacetedSearchStringFilterRequest]
        """
        self._search_string_filters = search_string_filters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
